@@ -58,6 +58,7 @@ static gint db_sort_asc(gpointer a, gpointer b);
 static gint db_sort_desc(gpointer a, gpointer b);
 static gint db_friends_find(gpointer a, gpointer b);
 static gint db_sort_time(gpointer a, gpointer b);
+static gint db_friends_online(gpointer _data, gpointer _filter);
 
 /**
  * @brief get profile form services 
@@ -114,6 +115,8 @@ xmlDocPtr DB_SEND_REQUEST(xmlDocPtr ui_request)
 			db_request = db_generate_message(db_request, INFO_MESSAGE, 
 	                                         DB_INIT_ERROR_TEXT, 
                                              DB_INIT_ERROR_CODE);
+	        xmlFree(ui_request);	        
+            xmlXPathFreeObject(Obj);
             return db_request;  
     }
 
@@ -168,8 +171,9 @@ xmlDocPtr DB_SAVE_PROFILE(xmlDocPtr drv_response) {
 	xmlXPathObject* Obj = db_xpath(RESPONSE_TAG_XPATH, drv_response);	
 	xmlNodePtr node_set = Obj->nodesetval->nodeTab[0];
 	gchar* resp_class = (gchar*)xmlGetProp(node_set,BAD_CAST "class");
+        xmlXPathFreeObject(Obj);
 
-	if (strcmp(resp_class, CLASS_PROFILE) == 0) {
+	if(strcmp(resp_class, CLASS_PROFILE) == 0) {
 
 		/** try to save in db **/
 		/** get profile id **/
@@ -213,6 +217,7 @@ xmlDocPtr DB_SAVE_PROFILE(xmlDocPtr drv_response) {
 				xmlNodePtr node_set = Obj->nodesetval->nodeTab[0];
 				xmlSetProp(node_set, BAD_CAST "id", BAD_CAST id);			
 			}
+                        xmlXPathFreeObject(Obj);
 
 		}		
 
@@ -223,7 +228,6 @@ xmlDocPtr DB_SAVE_PROFILE(xmlDocPtr drv_response) {
 
 	}
 
-    xmlXPathFreeObject(Obj);
     xmlFreeDoc(drv_response);
     g_free(resp_class);
 
@@ -304,6 +308,7 @@ xmlDocPtr DB_SAVE_FRIENDS(xmlDocPtr drv_response)
 	gchar* friends_id = NULL;
 	gchar* resp_xpath = NULL;
 	gint i;
+    gboolean save_error = FALSE;
 
 	/** if class FRIENDS, else error **/
 	if (strcmp(resp_class, CLASS_FRIENDS) == 0) {
@@ -312,30 +317,38 @@ xmlDocPtr DB_SAVE_FRIENDS(xmlDocPtr drv_response)
 		xmlXPathObject* Obj = db_xpath(resp_xpath, drv_response);	
 
 		for (i=0; i<Obj->nodesetval->nodeNr; i++) {
+		    node_set = Obj->nodesetval->nodeTab[i];
+            
+            if (node_set == NULL) {
+                save_error = TRUE;
+                continue;            
+            }
 
-			node_set = Obj->nodesetval->nodeTab[i];
-			db_resp = xmlNewDoc(BAD_CAST XML_VERSION);
-			friends_id = (gchar*)xmlGetProp(node_set, BAD_CAST "id");
-
-			xmlUnlinkNode(node_set);
-			xmlDocSetRootElement(db_resp, node_set);
+            db_resp = xmlNewDoc(BAD_CAST XML_VERSION);
+		    friends_id = (gchar*)xmlGetProp(node_set, BAD_CAST "id");
+		    xmlUnlinkNode(node_set);
+		    xmlDocSetRootElement(db_resp, node_set);
 			
-			if (create_or_update_contact(db_resp, friends_id) == 0) {
-				db_resp = xmlParseDoc(BAD_CAST db_message); 
-				db_resp = db_generate_message(db_resp, INFO_MESSAGE, 
-					                      DB_SAVE_MESSAGE_FRIENDS_TEXT, 
-                                                              DB_SAVE_MESSAGE_FRIENDS_CODE);							
+		    if (create_or_update_contact(db_resp, friends_id) != 0) {
+                save_error = TRUE;
 			}
-	
+            g_free(friends_id);
+            xmlFreeDoc(db_resp);	
 		} 	
 		
-		if (i == 0) {
+		if (i == 0 || save_error == TRUE) {
+
 			db_resp = xmlParseDoc(BAD_CAST db_message); 
 			db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
 					  DB_SAVE_ERROR_FRIENDS_TEXT, 
 					  DB_SAVE_ERROR_FRIENDS_CODE);									
-		}
-			
+		} else { 
+
+			db_resp = xmlParseDoc(BAD_CAST db_message); 
+			db_resp = db_generate_message(db_resp, INFO_MESSAGE, 
+				                          DB_SAVE_MESSAGE_FRIENDS_TEXT, 
+                                          DB_SAVE_MESSAGE_FRIENDS_CODE);							        
+        }
 	} else {
 
 		rem_targets(db_resp);
@@ -347,7 +360,6 @@ xmlDocPtr DB_SAVE_FRIENDS(xmlDocPtr drv_response)
     xmlFreeDoc(drv_response);
     
     g_free(resp_class);	
-    g_free(friends_id);
     g_free(resp_xpath);
 
     g_debug("DB_SAVE_FRIENDS: END");
@@ -356,6 +368,7 @@ xmlDocPtr DB_SAVE_FRIENDS(xmlDocPtr drv_response)
 }
 
 
+// NEW
 /**
  * @brief get response friends list from db to ui
  * @drv_response - request to db from ui  
@@ -367,6 +380,137 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
 
 	xmlDocPtr struct_response = xmlParseDoc(BAD_CAST db_response);
 	xmlDocPtr db_resp;
+
+    xmlDocPtr fr_resp = xmlParseDoc(BAD_CAST "<Params><array name=\"contacts\"/></Params>");
+    xmlNodePtr fr_resp_root = xmlDocGetRootElement(fr_resp);
+    xmlNodePtr fr_resp_node = fr_resp_root->children;
+
+    gint fr_from = 0;
+    gint fr_to = 0;
+
+    gchar* fr_from_str = NULL;
+    gchar* fr_to_str = NULL;            
+
+    xmlDocPtr friends = NULL;
+    
+    gboolean is_online_req = FALSE;
+    gboolean is_filter_req = FALSE;        
+
+    gint sort_order = ORDER_NO;
+
+    /** get parametrs in Params node**/
+    xmlXPathObject* Obj = db_xpath(REQUEST_PARAMS_TAG_XPATH, request);
+    if (Obj->nodesetval->nodeNr != 0) {
+        xmlNodePtr node_set = node_set = Obj->nodesetval->nodeTab[0];
+
+        /** get From **/
+        fr_from_str = (gchar*) xmlGetProp(node_set, BAD_CAST "From");
+        if (fr_from_str != NULL) {
+                fr_from = atoi((char*)fr_from_str);
+        } else {
+                fr_from_str = g_strdup("0");
+                fr_from = 0;
+        }
+
+
+        /** get TO **/
+        fr_to_str = (gchar*) xmlGetProp(node_set, BAD_CAST "To");
+        if (fr_to_str != NULL) {
+                fr_to = atoi(fr_to_str);
+        } else {
+                fr_to_str = g_strdup("10");
+                fr_to = 10;
+        }
+
+        /** type of sort list if NULL then no sort **/
+        xmlChar* str = xmlGetProp(node_set, BAD_CAST "Sort");
+        if (str != NULL) {
+            if (strcmp((char*)str,(char*)"asc") == 0) {
+                   sort_order = ORDER_ASC;
+            } 
+            
+            if (strcmp((char*)str,(char*)"desc") == 0) {
+                   sort_order = ORDER_DESC;                                    
+            }
+        }
+        xmlFree(str);
+
+
+        /** filter if null or empty then no filter **/
+        str = xmlGetProp(node_set, BAD_CAST "Filter");
+        if (str != NULL && strlen((char*)str) > 0) {
+            friends = search_contacts((const gchar*) str);  
+            is_filter_req = TRUE;
+            xmlSetProp(fr_resp_node, BAD_CAST "Filter", BAD_CAST str);
+        } // if (str) > 0
+        xmlFree(str);
+
+        /** online, 1 - only online users, 0 - online + offline **/
+        str = xmlGetProp(node_set, BAD_CAST "Online");
+        if (str != NULL && strcmp(str,"0") != 0) {
+     
+            friends = get_online_contacts(sort_order);
+            is_online_req = TRUE;
+            xmlSetProp(fr_resp_node, BAD_CAST "Online", "1");			
+	    }
+
+    }        
+
+    gint friends_count = 0;
+    
+    if (is_online_req == FALSE && is_filter_req == FALSE) {
+        friends = get_contacts_filter(fr_from_str, fr_to_str, sort_order, &friends_count);
+    }
+
+    /** error **/
+    if (friends == NULL) {
+        db_resp = xmlParseDoc(BAD_CAST db_message);
+        db_resp = db_generate_message(db_resp,  ERROR_MESSAGE,
+                                                DB_GET_ERROR_FRIENDS_TEXT,
+                                                DB_GET_ERROR_FRIENDS_CODE);
+        return db_resp;
+    }
+    
+    xmlSetProp(fr_resp_node, BAD_CAST "friendsQuantity", 
+            BAD_CAST g_strdup_printf("%d", friends_count));       
+
+    xmlNodePtr friends_root = xmlDocGetRootElement(friends);
+
+    xmlNodePtr friends_nodes = friends_root->children;
+    friends_root->children = NULL;
+    
+    while (friends_nodes != NULL) {
+        xmlNodePtr tmpNode = friends_nodes->next;
+        xmlUnlinkNode(friends_nodes);            
+        xmlAddChild(fr_resp_node, friends_nodes);
+        friends_nodes = tmpNode;
+    }
+
+    xmlFreeDoc(friends);
+
+        
+    db_resp = db_generate_response(struct_response, fr_resp_root,
+                                                   CLASS_FRIENDS, GET_FRIENDS);
+    xmlXPathFreeObject(Obj);
+
+
+    g_debug("db_get_profile: END");
+    return db_resp;
+}
+
+
+
+/**
+ * @brief get response friends list from db to ui
+ * @drv_response - request to db from ui  
+ * @return db_response - response for ui from db, or NULL if error
+**/
+xmlDocPtr DB_GET_FRIENDS_OLD(xmlDocPtr request)
+{
+	g_debug("db_get_friends: START");
+
+	xmlDocPtr struct_response = xmlParseDoc(BAD_CAST db_response);
+	xmlDocPtr db_resp;
 	GSList* response_list = NULL;
 
 	response_list = get_contacts(FALSE);
@@ -428,12 +572,13 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
                     }
                     xmlFree(str);
 
+					xmlDocPtr cur_data = NULL;
+					GSList* list_element = NULL;
+
                     /** filter if null or empty then no filter **/
                     str = xmlGetProp(node_set,BAD_CAST "Filter");
                     if (str != NULL && strlen((char*)str) > 0) {
 
-                            //GSList* find_element;
-                            GSList* list_element;
 
                             fr_to = 1;
                             fr_from = 0;
@@ -442,7 +587,7 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
                             response_list = NULL;
 
                             while (list_element != NULL) {
-				    xmlDocPtr cur_data = (xmlDocPtr)list_element->data;
+				                    cur_data = (xmlDocPtr)list_element->data;
                                     list_element = g_slist_remove(list_element, cur_data);
                                     if (db_friends_find(cur_data, (gpointer)str) == 0) {
                                             response_list = g_slist_append(response_list, cur_data);
@@ -457,14 +602,43 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
                     } // if (str) > 0
                     xmlFree(str);
 
+                    /** online, 1 - only online users, 0 - online + offline **/
+                    str = xmlGetProp(node_set,BAD_CAST "Online");
+                    if (str != NULL && strcmp(str,"0") != 0) {
+							
+							//GSList* find_element;
+                            GSList* list_element;
+
+                            fr_to = 1;
+                            fr_from = 0;
+
+                            list_element = response_list;
+                            response_list = NULL;
+
+							while (list_element != NULL) {
+								cur_data = (xmlDocPtr)list_element->data;
+								list_element = g_slist_remove(list_element, cur_data);
+							    if (db_friends_online(cur_data, str) == 0) {
+								    response_list = g_slist_append(response_list, cur_data);
+								    fr_to++;
+							    }else{
+							        xmlFreeDoc(cur_data);
+							    }
+							}
+
+                            xmlSetProp(fr_resp_node, BAD_CAST "friendsQuantity", BAD_CAST g_strdup_printf("%d", fr_to - 1));
+                            xmlSetProp(fr_resp_node, BAD_CAST "Online", "1");			
+					}
+                    
+
         }// if req ok
 
         /** error **/
-        if (response_list == NULL ) {
-                db_resp = xmlParseDoc(BAD_CAST db_message);
-                db_resp = db_generate_message(db_resp, ERROR_MESSAGE,
-                                                                  DB_GET_ERROR_FRIENDS_TEXT,
-                                                                  DB_GET_ERROR_FRIENDS_CODE);
+        if (response_list == NULL || (fr_to - 1) == 0) {
+            db_resp = xmlParseDoc(BAD_CAST db_message);
+            db_resp = db_generate_message(db_resp,  ERROR_MESSAGE,
+                                                    DB_ERROR_SEARCH_FRIENDS_TEXT,
+                                                    DB_ERROR_SEARCH_FRIENDS_CODE);
             return db_resp;
         }
 
@@ -536,23 +710,29 @@ xmlDocPtr DB_SAVE_BINARY_DATA(xmlDocPtr drv_response)
 	}
 
 	/** save binary data in db **/
+	gchar* binary_id;
+	gchar* binary_content;
 	for (node_bin = node; node_bin != NULL; node_bin = node_bin->next) {
 
 		g_debug("db: try save in bd %s",xmlGetProp(node_bin,BAD_CAST "uri"));
 
 		/** if uri empty **/	
-		if (strlen((char*)xmlGetProp(node_bin, BAD_CAST "uri")) > 0) {
-		
-			if ( set_binary_data_content((gchar*)xmlGetProp(node_bin,BAD_CAST "uri"),
-										 (gchar*)xmlNodeGetContent(node_bin)) != TRUE ) {
+		binary_id = (gchar*)xmlGetProp(node_bin,BAD_CAST "uri");
+		if (strlen(binary_id) > 0) {
+		        binary_content = (gchar*)xmlNodeGetContent(node_bin);
+			if ( set_binary_data_content(binary_id, binary_content) != TRUE ) {
 
 				db_resp = xmlParseDoc(BAD_CAST db_message); 
 				db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
                                                               DB_SAVE_ERROR_BINARY_TEXT, 
 							      DB_SAVE_ERROR_BINARY_CODE);
+				g_free(binary_id);
+				g_free(binary_content);
 				return db_resp;
 	
 			} // set binary
+			g_free(binary_id);
+			g_free(binary_content);
 		} // if uri
 	} // for
 
@@ -618,6 +798,8 @@ xmlDocPtr DB_SAVE_INBOX_MESSAGES(xmlDocPtr drv_response)
 
 	gchar* message_id;
 
+    gboolean save_error = FALSE;
+
 	if (Obj->nodesetval->nodeNr != 0) {	
 		node = Obj->nodesetval->nodeTab[0];
 
@@ -637,41 +819,179 @@ xmlDocPtr DB_SAVE_INBOX_MESSAGES(xmlDocPtr drv_response)
 
         node = Obj->nodesetval->nodeTab[i];
 
+        if (node == NULL) {
+            save_error = TRUE;
+            continue;        
+        }
+
 		db_resp = xmlNewDoc(BAD_CAST XML_VERSION);
 		message_id = (gchar*)xmlGetProp(node,BAD_CAST "id");
-	
-		xmlUnlinkNode(node);
+	    xmlUnlinkNode(node);
 		xmlDocSetRootElement(db_resp, node);
 				
-		if (save_func(db_resp, message_id) != 0)
-		{
-			db_resp = xmlParseDoc(BAD_CAST db_message); 
+		if (save_func(db_resp, message_id) != 0) {
+            save_error = TRUE;
+		}
+		g_free(message_id);  
+        xmlFreeDoc(db_resp);
+	}
+
+    xmlXPathFreeObject(Obj);
+    xmlFreeDoc(drv_response);
+    
+    if(save_error == TRUE || i == 0) {
+            db_resp = xmlParseDoc(BAD_CAST db_message); 
 			db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
                                                    text_error, 
                                                    code_error);
-            xmlFreeDoc(drv_response);
-            xmlXPathFreeObject(Obj);
-			return db_resp;		
-		}
-		g_free(message_id);
-	}   
-    xmlFreeDoc(db_resp);
-	
-    db_resp = xmlParseDoc(BAD_CAST db_message); 
-	db_resp = db_generate_message(db_resp, INFO_MESSAGE, text_ok, code_ok);
-    
-    xmlFreeDoc(drv_response);
-    xmlXPathFreeObject(Obj);
-	return db_resp;		
+    } else {
+            db_resp = xmlParseDoc(BAD_CAST db_message); 
+            db_resp = db_generate_message(db_resp, INFO_MESSAGE, text_ok, code_ok);
+    }    
+   
+    return db_resp;		
 	
 }
 
+
+// NEW
 /**
  * @brief get message in db 
  * @drv_response - response from db to ui
  * @return db_response - response from db to ui
 **/
 xmlDocPtr DB_GET_INBOX_MESSAGES(xmlDocPtr ui_request)
+{
+    /** get function **/    
+    GSList* response_list = NULL;
+    xmlNodePtr node_root = xmlNewNode(NULL, BAD_CAST "Params");
+    xmlNodePtr node_array = xmlNewNode(NULL, BAD_CAST "array");
+    xmlAddChild(node_root, node_array);
+
+    xmlDocPtr struct_resp = xmlParseDoc(BAD_CAST db_response);
+
+    gint messages_from = 0;
+    gint messages_to = 0;
+    gchar* messages_from_str = NULL;
+    gchar* messages_to_str = NULL;
+
+   /** get parametrs in Params node**/
+   xmlXPathObjectPtr Obj = db_xpath(REQUEST_PARAMS_TAG_XPATH, ui_request);
+   if (Obj->nodesetval->nodeNr != 0) {
+       xmlNodePtr node_set = Obj->nodesetval->nodeTab[0];
+
+       /** get From **/			
+       gchar* str = (gchar*)xmlGetProp(node_set, BAD_CAST "From");
+      
+       if (str != NULL) {
+             messages_from = atoi(str);
+       } else {
+             messages_from = 0;			
+       }
+       g_free(str);        
+       
+       messages_from_str =  g_strdup_printf("%d", messages_from);
+       xmlSetProp(node_root, BAD_CAST "From", BAD_CAST messages_from_str);
+
+	    /** get TO **/ 
+	    str = (gchar*)xmlGetProp(node_set,BAD_CAST "To");
+	    if (str != NULL) {
+		    messages_to = atoi(str);
+	    } else {
+		    messages_to = 10;			
+	    } 
+	
+        messages_to_str = g_strdup_printf("%d", messages_to);
+        xmlSetProp(node_root, BAD_CAST "To", BAD_CAST messages_to_str);
+            g_free(str);
+   }
+
+    guint messages_count = 0;
+    xmlDocPtr messages = NULL;
+    
+        gchar* text_error = NULL;
+    gchar* code_error = NULL;
+    gchar* cur_function = NULL;
+    
+    Obj = db_xpath(REQUEST_TAG_XPATH, ui_request);
+    if (Obj->nodesetval->nodeNr != 0 ) {
+        xmlNodePtr func_node = Obj->nodesetval->nodeTab[0];
+        
+        xmlChar* func_name = xmlGetProp(func_node,BAD_CAST "function");
+        if (strcmp((char*)func_name, GET_INBOX_MESSAGES) == 0){
+//            response_list = get_messages();
+            messages = get_messages_with_filter(messages_from_str, messages_to_str, &messages_count);
+            text_error = DB_GET_ERROR_INBOX_MESSAGES_TEXT;
+            code_error = DB_GET_ERROR_INBOX_MESSAGES_CODE;
+            cur_function = GET_INBOX_MESSAGES;    
+        }
+
+        if (strcmp((char*)func_name, GET_OUTBOX_MESSAGES) == 0){
+    //        return DB_GET_INBOX_MESSAGES_(ui_request);
+            messages = get_owner_messages_with_filter(messages_from_str, messages_to_str, &messages_count);
+            text_error = DB_GET_ERROR_OUTBOX_MESSAGES_TEXT;
+            code_error = DB_GET_ERROR_OUTBOX_MESSAGES_CODE;      
+            cur_function = GET_OUTBOX_MESSAGES;        
+        }    
+        xmlFree(func_name);        
+    
+    }
+    xmlXPathFreeObject(Obj);
+    
+    
+    
+    
+    g_free(messages_from_str);
+    g_free(messages_to_str);
+
+    /** error **/
+    if (messages == NULL ) {
+
+        xmlDocPtr db_resp = xmlParseDoc(BAD_CAST db_message); 
+        db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
+                                               DB_GET_ERROR_OUTBOX_MESSAGES_TEXT,
+		                                       DB_GET_ERROR_OUTBOX_MESSAGES_CODE);
+      printf("\nEND\n");
+        return db_resp;
+   }
+
+   gchar* text_count = g_strdup_printf("%d", messages_count);		
+    xmlSetProp(node_root, BAD_CAST "messagesQuantity", BAD_CAST text_count);
+    g_free(text_count);
+
+    xmlNodePtr messages_root = xmlDocGetRootElement(messages);
+
+    xmlNodePtr messages_nodes = messages_root->children;
+    messages_root->children = NULL;
+    
+    while (messages_nodes != NULL) {
+        xmlNodePtr tmpNode = messages_nodes->next;
+        xmlUnlinkNode(messages_nodes);            
+        xmlAddChild(node_array, messages_nodes);
+        messages_nodes = tmpNode;
+    }
+
+    xmlFreeDoc(messages);
+
+
+
+    xmlDocPtr db_resp = db_generate_response(struct_resp, node_root,
+				   CLASS_BOX_MESSAGE, GET_OUTBOX_MESSAGES);//cur_function);
+    
+    xmlFreeDoc(ui_request);
+    //xmlXPathFreeObject(Obj);
+
+    return db_resp;
+}
+
+
+
+/**
+ * @brief get message in db 
+ * @drv_response - response from db to ui
+ * @return db_response - response from db to ui
+**/
+xmlDocPtr DB_GET_INBOX_MESSAGES_OLD(xmlDocPtr ui_request)
 {
     /** get function **/    
     GSList* response_list = NULL;
@@ -793,6 +1113,7 @@ xmlDocPtr DB_GET_INBOX_MESSAGES(xmlDocPtr ui_request)
 				   CLASS_BOX_MESSAGE, cur_function);
     
     xmlFreeDoc(ui_request);
+    //xmlXPathFreeObject(Obj);
     g_free(str);
     return db_resp;
 }
@@ -1134,6 +1455,33 @@ static gint db_friends_find(gpointer _data, gpointer _filter)
 		name = (xmlChar*)g_utf8_strdown((gchar*)xmlNodeGetContent(node_data), -1);
 		filter = (xmlChar*)g_utf8_strdown((gchar*)filter, -1);
 		if (xmlStrcasestr(name, filter) != NULL) {
+                xmlXPathFreeObject(Obj);
+			return 0;		
+		}	
+	}
+	
+    xmlXPathFreeObject(Obj);	
+	return 1;	
+}
+
+/**
+ * @brief search online friends
+ */
+static gint db_friends_online(gpointer _data, gpointer _filter)
+{
+	xmlChar* filter = (xmlChar*)_filter;
+	xmlChar* name;
+	xmlDocPtr doc_data = (xmlDocPtr)_data;
+
+	xmlXPathObject *Obj = db_xpath("//struct/string[@name='FriendStatus']", doc_data);
+	
+	if (Obj->nodesetval->nodeNr > 0) {
+		xmlNodePtr node_data = Obj->nodesetval->nodeTab[0];
+		name = (xmlChar*)g_utf8_strdown((gchar*)xmlNodeGetContent(node_data), -1);
+		filter = (xmlChar*)g_utf8_strdown((gchar*)filter, -1);
+		if (xmlStrcasestr(name, filter) != NULL) {
+		    xmlFree(name);
+		    xmlXPathFreeObject(Obj);
 			return 0;		
 		}	
 	}
@@ -1143,3 +1491,4 @@ static gint db_friends_find(gpointer _data, gpointer _filter)
 
 }
 
+
