@@ -58,9 +58,12 @@ static const gchar* const schemas_list[SCHEMAS_COUNT + 1] = {
     SCHEMA_NAME_METACONTACTS, 
     SCHEMA_NAME_CONTACTS,
     SCHEMA_NAME_CONTACTS_LIST,  
+    SCHEMA_NAME_CONTACTS_LIST_FILTER,
 //    SCHEMA_NAME_SERVICES, 
     SCHEMA_NAME_MESSAGES,
-    SCHEMA_NAME_OWNER_MESSAGES,  
+    SCHEMA_NAME_OWNER_MESSAGES,
+    SCHEMA_NAME_MESSAGES_FILTER,
+    SCHEMA_NAME_OWNER_MESSAGES_FILTER,        
     NULL
 };
 
@@ -126,8 +129,11 @@ static gchar* build_binary_nodes_select_query();//(const gchar* schema_name);
 
 gchar* db_get_binary_data_content(const gchar* binary_id)
 {
-    gchar* inner_binary_id = g_base64_encode((const guchar*)binary_id, strlen(binary_id));
-
+    gchar* inner_binary_id = NULL;
+    if (strlen(binary_id) > 0)
+    {
+	inner_binary_id = g_base64_encode((const guchar*)binary_id, strlen(binary_id));
+    }
     gchar* db_path = cm_get_db_path_by_name_or_default(g_db_name);
     
     gchar* dir_path = g_strconcat(db_path, G_DIR_SEPARATOR_S, 
@@ -151,7 +157,11 @@ gchar* db_get_binary_data_content(const gchar* binary_id)
 
 gboolean db_set_binary_data_content(const gchar* binary_id, const gchar* content)
 {
-    gchar* inner_binary_id = g_base64_encode((const guchar*)binary_id, strlen(binary_id));
+    gchar* inner_binary_id = NULL;
+    if (strlen(binary_id) > 0)
+    {
+	inner_binary_id = g_base64_encode((const guchar*)binary_id, strlen(binary_id));
+    }
     gchar* db_path = cm_get_db_path_by_name_or_default(g_db_name);
     gchar* dir_path = g_strconcat(db_path, G_DIR_SEPARATOR_S, 
                                   BINARY_DIR_NAME, G_DIR_SEPARATOR_S, NULL);
@@ -300,13 +310,16 @@ static gint prepare_binary_data_fo_save(const gchar* schema_name, xmlDocPtr doc)
             if (bin_id == NULL) {
                 continue;
             }
-            gchar* md5 =
 //            		cvs_MD5Init (&context);
 //		cvs_MD5Update (&context, bin_id, strlen(bin_id));
 //		cvs_MD5Final (checksum, &context);
 //		DB_P2DEBUG(3, "checksum = %s, bin_id = %s", checksum, bin_id);
-        
-             g_base64_encode((const guchar*)bin_id, strlen(bin_id));
+
+            gchar* md5 = NULL;
+            if (strlen(bin_id) > 0)
+            {
+        	md5 = g_base64_encode((const guchar*)bin_id, strlen(bin_id));
+            }
 //            md5_get_digest(bin_id, -1, md5);
 //             = g_compute_checksum_for_string(G_CHECKSUM_MD5, bin_id, -1);
             gchar* filepath = g_strconcat(tmp_path, G_DIR_SEPARATOR_S, md5, NULL);
@@ -361,7 +374,10 @@ gint load_binary_data_to_doc(const gchar* schema_name, xmlDocPtr doc)
         for(gint i = size; i >= 0; --i) {
             gchar* bin_id = (gchar*)xmlGetProp(nodeset->nodeTab[i], BAD_CAST BINARY_NODE_TAG_FOR_FILENAME);
               DB_PDEBUG(3, "bin_id %s", bin_id);
-            gchar* md5 = g_base64_encode((const guchar*)bin_id, strlen(bin_id));
+            gchar* md5 = NULL;
+            if (strlen(bin_id) > 0) {
+        	md5 = g_base64_encode((const guchar*)bin_id, strlen(bin_id));
+    	    }
 //            md5_get_digest(bin_id, -1, md5);
 //             = g_compute_checksum_for_string(G_CHECKSUM_MD5, bin_id, -1);
             gchar* filepath = g_strconcat(tmp_path, G_DIR_SEPARATOR_S, md5, NULL);
@@ -1094,7 +1110,7 @@ static gint create_path(const gchar* db_name)
     if (db_path == NULL && is_str_null_or_empty(db_name) == TRUE) {
         db_path = g_strconcat(HOME_DIR, G_DIR_SEPARATOR_S, PROGRAM_DIR_NAME, 
                               G_DIR_SEPARATOR_S, PROGRAM_DB_NAME, NULL);
-    } else {
+    } else if (db_path == NULL) {
        db_path = g_strconcat(HOME_DIR, G_DIR_SEPARATOR_S, PROGRAM_DIR_NAME, 
                              G_DIR_SEPARATOR_S, PROGRAM_DB_NAME, G_DIR_SEPARATOR_S, db_name, NULL);
     }
@@ -1661,7 +1677,6 @@ gint db_add_data_to_db_with_id(const gchar* schema_name, const xmlDocPtr new_dat
  */
 void db_prepare(const gchar* db_name)
 {
-    
     create_path(db_name);
     build_schemas_links();
  
