@@ -39,6 +39,16 @@
 
 #define XPATH_NAME_SURNAME "//Params/string[@name=\"FirstName\" or @name=\"LastName\"]"
 
+#define XSLT_PARAM_POS_FROM "FROM"
+#define XSLT_PARAM_POS_TO "TO"
+#define XSLT_PARAM_ALL_NODES "ALL"
+#define XSLT_PARAM_SEARCH_DATA "SEARCH"
+#define XSLT_PARAM_ONLINE_CONTACS "ONLINE"
+#define XSLT_PARAM_ORDER "ORDER"
+#define XSLT_PARAM_ORDER_DESC "1"
+#define XSLT_PARAM_ORDER_ASC "2"
+
+
 gint create_owner_metacontact(xmlDocPtr doc) {
       
     if (doc == NULL) {
@@ -193,6 +203,92 @@ GSList* db_get_owner_profile()
 }
 
 
+
+static gint count_table_records(xmlDocPtr doc)
+{
+    if (doc == NULL) {
+        return 0;
+    }
+    
+    xmlNodePtr root = xmlDocGetRootElement(doc);
+    
+    if (root == NULL) {
+        return 0;
+    }
+    
+    if (root->children == NULL) {
+        return 0;
+    }    
+    
+    xmlNodePtr node = root->children;
+    
+    gint counter = 0;
+    while (node != NULL) {
+        ++counter;
+        node = node->next;
+    }
+
+    return counter;
+}
+
+
+
+xmlDocPtr get_filtered_messages(const gchar* schema_name, const gchar* schema_name_filter,
+        const gchar* from, const gchar* to, gint *quantity)
+{
+   xmlDocPtr messages_list_table = get_table_from_list(schema_name);    
+    
+    *quantity = count_table_records(messages_list_table);
+    
+    gchar** params = NULL;
+    
+    if (from == NULL || to == NULL) {
+        params = g_new(gchar*, 3);    
+        params[0] = g_strdup("ALL");
+        params[1] = g_strdup("1");
+        params[2] = NULL;       
+    } else {
+        params = g_new(gchar*, 5);    
+        params[0] = g_strdup("FROM");
+        params[1] = g_strdup(from);
+        params[2] = g_strdup("TO");
+        params[3] = g_strdup(to);
+        params[4] = NULL;       
+    }
+    
+
+    xmlDocPtr external_format = 
+        db_apply_revers_stylesheet(schema_name_filter, 
+            (const xmlDocPtr) messages_list_table, (const gchar**) params);
+    g_strfreev(params);
+
+    if (external_format == NULL) {
+        return NULL;
+    }    
+    
+    if (xmlDocGetRootElement(external_format) == NULL) {
+        xmlFreeDoc(external_format);
+        external_format = NULL;
+    }
+
+    return external_format;
+}        
+
+xmlDocPtr get_owner_messages_with_filter(const gchar* from, const gchar* to, gint *quantity) 
+{
+    return get_filtered_messages(SCHEMA_NAME_OWNER_MESSAGES, 
+                SCHEMA_NAME_OWNER_MESSAGES_FILTER, from, to, quantity);
+}
+
+
+xmlDocPtr get_messages_with_filter(const gchar* from, const gchar* to, gint *quantity) 
+{
+    return get_filtered_messages(SCHEMA_NAME_MESSAGES, 
+                SCHEMA_NAME_MESSAGES_FILTER, from, to, quantity);
+}
+
+
+
 GSList* get_messages() 
 {
 
@@ -283,6 +379,122 @@ GSList* get_owner_messages()
 
 
 
+
+xmlDocPtr get_contacts_filter(const gchar* from, const gchar* to, gint order, gint *quantity) 
+{
+
+     xmlDocPtr contacts_list_table = get_table_from_list(SCHEMA_NAME_CONTACTS_LIST);    
+    
+    *quantity = count_table_records(contacts_list_table);
+
+    gchar** params = g_new(gchar*, 9);
+    params[0] = g_strdup(XSLT_PARAM_ALL_NODES);
+    params[1] = g_strdup("1");
+    params[2] = g_strdup(XSLT_PARAM_POS_FROM);
+    params[4] = g_strdup(XSLT_PARAM_POS_TO);
+    params[6] = g_strdup(XSLT_PARAM_ORDER);
+    params[8] = NULL;       
+
+    if (order == ORDER_DESC) {
+        params[7] = g_strdup(XSLT_PARAM_ORDER_DESC);
+    } else if (order == ORDER_ASC) {
+        params[7] = g_strdup(XSLT_PARAM_ORDER_ASC);
+    }
+
+    if (from == NULL || to == NULL) {
+        params[3] = g_strdup("0");
+        params[5] = g_strdup("10");            
+    } else { 
+        params[3] = g_strdup(from);
+        params[5] = g_strdup(to);
+    }
+    
+
+    xmlDocPtr external_format = 
+        db_apply_revers_stylesheet(SCHEMA_NAME_CONTACTS_LIST_FILTER, 
+            contacts_list_table, params);
+    g_strfreev(params);
+
+    if (external_format == NULL) {
+        return NULL;
+    }    
+
+    if (xmlDocGetRootElement(external_format) == NULL) {
+        xmlFreeDoc(external_format);
+        external_format = NULL;
+    }
+
+    return external_format;
+}
+
+
+xmlDocPtr get_online_contacts(gint order) 
+{
+
+     xmlDocPtr contacts_list_table = get_table_from_list(SCHEMA_NAME_CONTACTS_LIST);    
+    
+    gchar** params = g_new(gchar*, 5);
+    params[0] = g_strdup(XSLT_PARAM_ONLINE_CONTACS);
+    params[1] = g_strdup("1");
+    params[2] = g_strdup(XSLT_PARAM_ORDER);
+    params[4] = NULL;       
+
+    if (order == ORDER_DESC) {
+        params[3] = g_strdup(XSLT_PARAM_ORDER_DESC);
+    } else if (order == ORDER_ASC) {
+        params[3] = g_strdup(XSLT_PARAM_ORDER_ASC);
+    }
+    
+
+    xmlDocPtr external_format = 
+        db_apply_revers_stylesheet(SCHEMA_NAME_CONTACTS_LIST_FILTER, 
+            contacts_list_table, params);
+    g_strfreev(params);
+
+    if (external_format == NULL) {
+        return NULL;
+    }    
+    
+    if (xmlDocGetRootElement(external_format) == NULL) {
+        xmlFreeDoc(external_format);
+        external_format = NULL;
+    }
+
+    return external_format;
+}
+
+
+xmlDocPtr search_contacts(const gchar* data) 
+{
+
+     xmlDocPtr contacts_list_table = get_table_from_list(SCHEMA_NAME_CONTACTS_LIST);    
+    
+    gchar** params = g_new(gchar*, 3);
+    params[0] = g_strdup(XSLT_PARAM_SEARCH_DATA);
+    params[1] = g_strconcat("\"", data, "\"", NULL);
+    params[2] = NULL;       
+
+    xmlDocPtr external_format = 
+        db_apply_revers_stylesheet(SCHEMA_NAME_CONTACTS_LIST_FILTER, 
+            contacts_list_table, params);
+    g_strfreev(params);
+
+    if (external_format == NULL) {
+        return NULL;
+    }    
+    
+    if (xmlDocGetRootElement(external_format) == NULL) {
+        xmlFreeDoc(external_format);
+        external_format = NULL;
+    }
+
+    return external_format;
+}
+
+
+
+
+
 GSList* get_contacts(gboolean with_owner) {
 
     xmlChar* ns = BAD_CAST cm_get_namespaces_key(SCHEMA_NAME_CONTACTS_LIST);
@@ -489,7 +701,10 @@ GSList* db_get_contact(gchar* id)
 
 GSList* db_get_owner_metacontact(gchar* id)
 {
-    return db_get_node_by_id(METACONTACTS_SCHEMA_NAME, id);
+    gchar* tmp_id = g_strconcat("\"", id, "\"", NULL);
+    GSList* list =  db_get_node_by_id(METACONTACTS_SCHEMA_NAME, tmp_id);
+    g_free(tmp_id);
+    return list;
 }
 
 GSList* db_get_owner_contacts(gchar* id)
