@@ -110,16 +110,19 @@ int msa_disp_init()
     result = gnome_vfs_directory_list_load(&list_dir, path,
                                            GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
 
+    g_free(path);
+
     if(result != GNOME_VFS_OK) {
         g_debug("disp:msa_disp_init: error no file in such directory %s", MODULE_PATH);
         return FAILURE;
     }
 
     /** pass on directory files **/
-    for (node = list_dir; node != NULL; node = node->next) {
-        
+    while (list_dir != NULL) {
+
         /** get folder name from GList **/
-        info = (GnomeVFSFileInfo*)node->data;
+        info = (GnomeVFSFileInfo*)list_dir->data;
+        list_dir = g_slist_remove(list_dir, info);
 
         /** if it isn't ".." or "." **/
         if (strcmp(info->name, "..") != 0 && strcmp(info->name, ".") != 0) {
@@ -139,8 +142,10 @@ int msa_disp_init()
                 save_module(module);        
             } else {
                 g_debug("disp:msa_disp_init: can't connect driver %s", module->msa_mod->id);            
-            }
-        }    
+            	g_free(module->msa_mod->id);
+	    }
+        }
+        gnome_vfs_file_info_unref(info);
     }
 
     /** init DB **/
@@ -154,6 +159,7 @@ int msa_disp_init()
        save_module(module);
     } else {
        g_debug("disp:msa_disp_init: db can't work!");     
+       g_free(module->msa_mod->id);
        return FAILURE;    
     }
 
@@ -192,11 +198,13 @@ static msa_module_disp* msa_disp_module_new()
 
 	module->msa_mod->send = NULL;
 	module->msa_mod->shutdown = NULL;
-	module->handle = NULL;
 	module->msa_mod->id = NULL;
 	module->msa_mod->name = NULL;
 	module->msa_mod->proxy = NULL;
+        module->msa_mod->pic = NULL;
 	module->msa_mod->port = 0;
+	module->handle = NULL;
+        module->data = NULL;
 
 	return module;
 }
@@ -247,6 +255,7 @@ static int msa_disp_driver_connect(msa_module_disp* mod)
     if (!handle) {
         g_debug("disp:msa_driver_connect:dlopen_error: %s", dlerror());
         mod->msa_mod->status = BROKEN;
+        g_free(path);
         return FAILURE;
     }
 
@@ -255,13 +264,17 @@ static int msa_disp_driver_connect(msa_module_disp* mod)
     if ((error = dlerror()) != NULL) {
         g_debug("disp:msa_module_connect:dlsym_error: %s", error);
         mod->msa_mod->status = BROKEN;
+        dlclose(handle);
+        g_free(path);
         return FAILURE;
     }
 
     driver_init_msa(mod->msa_mod);
     mod->msa_mod->status = ON;
     mod->msa_mod->set_events = handler_put_data;
-
+    mod->handle = handle;
+    
+    g_free(path);
     return SUCCESS;
 }
 
