@@ -564,11 +564,12 @@ static void processing()
     KERNEL_DEBUG(1) ("KERNEL: Processing START");
     guint index = 0;
 
-    while (index < repository_get_length() && is_process_proceed == TRUE) {
+    while (repository_get_length() > 0 && is_process_proceed == TRUE) {
         KERNEL_MESSAGE(3) ("KERNEL: Target Index = %i, all targets = %i", index, repository_get_length());
         transit_data* tr_data = repository_get_transit_data_by_index(index, FALSE); 	    
 
 	    if (tr_data == NULL) {   
+	        index = 0;
 	        repository_get_transit_data_by_index(index, TRUE);
 	        continue;
 	    }    
@@ -602,6 +603,12 @@ static void processing()
             continue;     
         }
         ++index;
+        
+        if (repository_get_length() == index) {
+            index =  0;
+            g_usleep(G_USEC_PER_SEC / 2);        
+        }       
+        
 	}
 
     G_LOCK(is_process_proceed);
