@@ -64,7 +64,6 @@ static void ui_start(gpointer _data, gpointer list_drv, int argc, char* argv[])
     /* DRIVERS */
     kernel = (msa_module*)_data;
     GList* list = (GList*)list_drv;
-    GList* node;
  
     /* GTK INIT */
     gtk_init(NULL, NULL);
@@ -92,14 +91,14 @@ int ui_got_response(xmlDocPtr response, xmlDocPtr* answer, msa_module* ui_info_n
         gchar* func = NULL;
         GSource* source = g_timeout_source_new(TIMEOUT);
         //hildon_gtk_window_set_progress_indicator (ui_data->window, 0);
-        
+
         if (get_function_from_response(response, &class_name, &func) == 0 ) {
             g_print("UI GOT RESPONSE: %s -> %s", class_name, func);
             if (strcmp(class_name, SETTINGS) == 0) {
                 /* SETTINGS */
                 if (strcmp(func, GET_SETTINGS) == 0) {
                     g_source_set_callback(source, G_CALLBACK(ui_driver_get_settings), (gpointer)response, NULL);
-                }  
+                }
             } else if (strcmp(class_name, PROFILE) == 0) {
                 /* PROFILE */
                 if (strcmp(func, GET_PROFILE) == 0) {     
@@ -180,14 +179,18 @@ gboolean ui_driver_get_profile(gpointer request)
     for (; children != NULL; children = children->next){
         gtk_widget_destroy(children->data); 
     }
+
+// !!!    
+    g_slist_free(children);
+    children = NULL;
     
     GtkWidget* vbox_left = gtk_vbox_new(TRUE, 0);
     GtkWidget* vbox_edit = gtk_vbox_new(TRUE, 0);
     GtkWidget* hbox_edit = gtk_hbox_new(FALSE, 0);
-    GtkWidget* hbox = gtk_hbox_new(FALSE, 0);
+// not used
+//    GtkWidget* hbox = gtk_hbox_new(FALSE, 0);
     GtkWidget* panarea = hildon_pannable_area_new();
     hildon_pannable_area_add_with_viewport(panarea, hbox_edit);
-    int i = 0;
     GtkWidget* detail;
     GtkWidget* label;
     xmlNodePtr cont; 
@@ -196,20 +199,24 @@ gboolean ui_driver_get_profile(gpointer request)
         gchar* type = (gchar*)node->name;
         if (!strcmp(type, TYPE_STRNG)) {
 // !!!
-            gchar* prop_val = xmlGetProp(node, "name");
-            label = ui_init_label(prop_val);
-            g_free(prop_val);
-            
+            xmlChar* prop_val = xmlGetProp(node, BAD_CAST "name");
+            label = ui_init_label(_(prop_val));
+            xmlFree(prop_val);
+
             detail = hildon_entry_new(HILDON_SIZE_FINGER_HEIGHT);
-            gtk_entry_set_text(GTK_ENTRY(detail), (gchar*)xmlNodeGetContent(node));
+// !!!
+            xmlChar* content = xmlNodeGetContent(node);
+            gtk_entry_set_text(GTK_ENTRY(detail), _((gchar*)content));
+            xmlFree(content);
+            
             gtk_box_pack_start(GTK_BOX(vbox_left), label, TRUE, TRUE, 0);        
             gtk_box_pack_start(GTK_BOX(vbox_edit), detail, TRUE, TRUE, 0);        
         } else if (!strcmp(type, TYPE_IMAGE)) {
             cont = node;
         } else if (!strcmp(type, TYPE_SELCT)) {
-            gchar* prop_val = xmlGetProp(node, "name");
-            label = ui_init_label(prop_val);
-            g_free(prop_val);
+            xmlChar* prop_val = xmlGetProp(node, BAD_CAST "name");
+            label = ui_init_label(_(prop_val));
+            xmlFree(prop_val);
             
             GtkWidget *selector = hildon_touch_selector_new_text ();
             detail = hildon_picker_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
@@ -219,36 +226,42 @@ gboolean ui_driver_get_profile(gpointer request)
             int n = 0;
             gchar *str_value;
             while (select != NULL) {
-                str_value = (gchar*)xmlGetProp(select, "selected");	
-		        if (!strcmp(str_value, "1")) {
+                str_value = (gchar*)xmlGetProp(select, BAD_CAST "selected");
+		if (!g_strcmp0(str_value, "1")) {
                     n = i;
                 }
                 g_free(str_value);
-    		    str_value = (gchar*)xmlNodeGetContent(select);							
-    		    hildon_touch_selector_append_text(selector, str_value);
-	    	    g_free(str_value);
+    		str_value = (gchar*)xmlNodeGetContent(select);
+    		hildon_touch_selector_append_text(selector, _(str_value));
+	    	g_free(str_value);
                 select = select->next;
                 i++;
             }
             hildon_touch_selector_set_active(selector, 0, n);
             //hildon_picker_button_set_done_button_text(detail, str_value);
 // !!!
-            prop_val = xmlGetProp(node, "name");
+            prop_val = xmlGetProp(node, BAD_CAST "name");
             gtk_widget_set_name(GTK_WIDGET(selector), prop_val);
-            g_free(prop_val);      
+            xmlFree(prop_val);
             
             hildon_button_set_value_alignment(detail, 0, 0.5);
             hildon_button_set_title_alignment(detail, 0, 0.5);
-            g_signal_connect(G_OBJECT(detail), "value-changed", G_CALLBACK(callback_combo_changed), (gpointer)xmlGetProp(node, "name"));
+
+// !!!
+            prop_val = xmlGetProp(node, BAD_CAST "name");
+            g_signal_connect(G_OBJECT(detail), "value-changed", G_CALLBACK(callback_combo_changed), (gpointer) prop_val);
+            //xmlFree(prop_val);
+            
             gtk_box_pack_start(GTK_BOX(vbox_left), label, TRUE, TRUE, 0);
             gtk_box_pack_start(GTK_BOX(vbox_edit), detail, FALSE, FALSE, 0);
             gtk_button_set_relief(GTK_WIDGET(detail), GTK_RELIEF_NONE);
         } else if (!strcmp(type, TYPE_DATE)) {
-            gchar* prop_val = (gchar*) xmlGetProp(node, "name");
-            label = ui_init_label(prop_val);
-            g_free(prop_val);
+            xmlChar* prop_val = xmlGetProp(node, BAD_CAST "name");
+            label = ui_init_label(_(prop_val));
+            xmlFree(prop_val);
             
 // !!            detail = ui_init_date_chooser(xmlGetProp(node, "name"), (gchar*)xmlNodeGetContent(node));
+
             detail = ui_init_date_chooser(NULL, (gchar*)xmlNodeGetContent(node));
             gtk_button_set_relief(GTK_WIDGET(detail), GTK_RELIEF_NONE);
             hildon_button_set_value_alignment(detail, 0, 0.5);
@@ -268,6 +281,8 @@ gboolean ui_driver_get_profile(gpointer request)
     pbloader = gdk_pixbuf_loader_new_with_type ("jpeg", NULL);
     gdk_pixbuf_loader_write(pbloader, buff, size, NULL);
     pixbuff = gdk_pixbuf_loader_get_pixbuf(pbloader);
+// !!!    
+    g_object_ref(pixbuff);
     int height = gdk_pixbuf_get_height(pixbuff);
     if (height > MAX_HEIGHT_PHOTO) {
         int width = gdk_pixbuf_get_width(pixbuff) * MAX_HEIGHT_PHOTO / height;
@@ -279,6 +294,9 @@ gboolean ui_driver_get_profile(gpointer request)
     GtkWidget* image = gtk_image_new_from_pixbuf(pixbuff);
     gtk_misc_set_alignment(GTK_MISC(image), 0.5, 0.5);
     gdk_pixbuf_loader_close(pbloader, NULL);
+
+// !!!
+    g_object_unref((gpointer) pbloader);
     g_free(buff);
     g_object_unref(pixbuff);
     g_free(undecoded);
@@ -333,15 +351,25 @@ static gpointer ui_init_detail(gchar* str_label, gchar* str_value)
 static gpointer ui_init_date_chooser(gchar* str_label, gchar* str_value)
 {
     gchar** numbers = g_strsplit(str_value, ".", 3);
-    gint y = atoi(numbers[2]);
-    gint m = atoi(numbers[1]) - 1;
-    gint d = atoi(numbers[0]);
+    gint y = 1900;
+    gint m = 0;
+    gint d = 0;
+    
+    if( numbers[0] != NULL && numbers[1] != NULL && numbers[2] != NULL){
+        g_debug("full date");
+        y = atoi(numbers[2]);
+        m = atoi(numbers[1]) - 1;
+        d = atoi(numbers[0]);
+    }
     g_strfreev(numbers);
     GtkWidget* button = hildon_date_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
     hildon_date_button_set_date (button, y, m, d);
+    
     hildon_button_set_title(button, NULL);
     hildon_button_set_value(button, str_value);
-    g_signal_connect(G_OBJECT(button), "value-changed", G_CALLBACK(callback_date_edit), (gpointer)str_value);
+// !!!
+    g_free(str_value);
+    g_signal_connect(G_OBJECT(button), "value-changed", G_CALLBACK(callback_date_edit), NULL);
     return button;
 }
 
@@ -354,37 +382,26 @@ gboolean ui_driver_get_friends(gpointer request)
     xmlXPathObject *Obj;
     xmlNodePtr node_root;
     xmlNodePtr node;
-    gchar* str_name;
-    gchar* str_status;
-    gchar* str_filter;    
-    gint i;
+    gchar* str_filter;
     int from = ui_data->page_frds * FRIENDS_PER_PAGE;
     int to = (ui_data->page_frds + 1) * FRIENDS_PER_PAGE;
-    gboolean send = FALSE;
     GtkWidget* vbox_friends = gtk_vbox_new(FALSE, 0);
     GtkWidget* panarea = hildon_pannable_area_new();
     GtkWidget* friend;
     Friend* struct_friend;
-    
+
     Obj = xpath(PARAMS_TAG_XPATH, request);
     node = Obj->nodesetval->nodeTab[0];
     g_hash_table_foreach_remove(ui_data->table_imgs, remove_friends_img, NULL);
     node_root = node->children;
 
-    xmlChar* prop_value = xmlGetProp(node,"friendsQuantity");
-    ui_data->num_frds = atoi((const char*)prop_value);
+    xmlChar* prop_value = xmlGetProp(node, BAD_CAST "friendsQuantity");
+    ui_data->num_frds = atoi((gchar *)prop_value);
     xmlFree(prop_value);
-    
-    str_filter = xmlGetProp(node, "Filter");
-    if (str_filter != NULL) {
-        if (strlen(str_filter) > 0) {
-            callback_friends_filter(str_filter);
-        } else {
-            callback_friends_filter(NULL);
-        }
-    } else {
-        callback_friends_filter(NULL);
-    }
+    xmlXPathFreeObject(Obj);
+
+    str_filter = xmlGetProp(node, BAD_CAST "Filter");
+
     if (to >  ui_data->num_frds) {
         to =  ui_data->num_frds;
     }
@@ -402,27 +419,40 @@ gboolean ui_driver_get_friends(gpointer request)
         gtk_widget_set_sensitive(GTK_WIDGET(ui_data->button_friends_page_next), TRUE);
         gtk_widget_set_sensitive(GTK_WIDGET(ui_data->button_friends_page_last), TRUE);
     }
-    gtk_label_set_text(GTK_LABEL(ui_data->label_friends_page), g_strdup_printf("%d - %d / %d", from + 1, to, ui_data->num_frds));
+
+    gchar *textLabel = g_strdup_printf("%d - %d / %d", from + 1, to, ui_data->num_frds);
+    gtk_label_set_text(GTK_LABEL(ui_data->label_friends_page), textLabel);
+    g_free(textLabel);
     
     /* REMOVE FRIENDS LIST */
     GList* children = gtk_container_get_children (GTK_CONTAINER(ui_data->box_friends_list));
     for (; children != NULL; children = children->next){
         gtk_widget_destroy(children->data); 
-    }    
-	hildon_pannable_area_add_with_viewport (panarea, vbox_friends);
+    }
+
+    hildon_pannable_area_add_with_viewport (panarea, vbox_friends);
     for (node = node_root; node != NULL; node = node->next) {
         struct_friend = struct_friend_create(1);
-        struct_friend->str_id = xmlGetProp(node, "id");
+        struct_friend->str_id = xmlGetProp(node, BAD_CAST "id");
         struct_friend->str_name = xmlNodeGetContent(node->children);
         struct_friend->str_status = xmlNodeGetContent(node->children->next);
         struct_friend->str_img = xmlNodeGetContent(node->children->next->next);
-        struct_friend->str_uri = xmlGetProp(node->children->next->next, "uri");
+        struct_friend->str_uri = xmlGetProp(node->children->next->next, BAD_CAST "uri");
         friend = ui_friend((gpointer)struct_friend);
         struct_friend_free(struct_friend);
         gtk_box_pack_start(GTK_BOX(vbox_friends), friend, FALSE, TRUE, 0);
     }
     gtk_box_pack_start(GTK_BOX (ui_data->box_friends_list), panarea, TRUE, TRUE, PADDING);
-    gtk_widget_show_all(ui_data->box_friends_list);    
+    gtk_widget_show_all(ui_data->box_friends_list);
+
+
+
+
+    
+    if (ui_data->friends_offline && str_filter == NULL) gtk_widget_show(ui_data->box_friends_navi);
+    else gtk_widget_hide(ui_data->box_friends_navi);
+    
+    g_free(str_filter);
     xmlFreeDoc(request);
     return FALSE; 
 }
@@ -431,7 +461,7 @@ gboolean ui_driver_get_friends(gpointer request)
 gboolean remove_friends_img(gpointer key, gpointer value, gpointer user_data)
 {
 	g_free(key);
-	gtk_widget_destroy(GTK_WIDGET(value));
+	//gtk_widget_destroy(GTK_WIDGET(value));
 	return TRUE;
 }
 
@@ -444,7 +474,7 @@ gboolean remove_friends_img(gpointer key, gpointer value, gpointer user_data)
 gpointer ui_friend(gpointer ptr_friend)
 {
     Friend* friend = ptr_friend;
-    GSource* source;    
+    //GSource* source;
     GtkWidget* label_name = gtk_label_new(NULL);
     GtkWidget* hbox = gtk_hbox_new(FALSE, PADDING);
     GtkWidget* image;    
@@ -453,33 +483,40 @@ gpointer ui_friend(gpointer ptr_friend)
     GtkWidget* box_button_prf = gtk_hbox_new(FALSE, 0);        
     GtkWidget* box_button_msg = gtk_hbox_new(FALSE, 0);
     gchar* ptr_str_id;
-    
+
+    gchar* labelText = NULL;
     if (!strcmp(friend->str_status, "1")) {
-        gtk_label_set_markup(GTK_LABEL(label_name), g_strconcat(MARKUP_ONLINE, friend->str_name, PUKRAM, NULL));
+        labelText = g_strconcat(MARKUP_ONLINE, friend->str_name, PUKRAM, NULL);
     } else {
-        gtk_label_set_markup(GTK_LABEL(label_name), g_strconcat(MARKUP_OFFLINE, friend->str_name, PUKRAM, NULL));
+        labelText = g_strconcat(MARKUP_OFFLINE, friend->str_name, PUKRAM, NULL);
     }
+    gtk_label_set_markup(GTK_LABEL(label_name), labelText);
+    g_free(labelText);
+
     gtk_misc_set_alignment(GTK_MISC(label_name), 0, 0.5);
     gtk_label_set_ellipsize(GTK_LABEL(label_name), PANGO_ELLIPSIZE_END);
     gtk_widget_set_name (GTK_WIDGET(label_name), friend->str_name);
     if (strlen(friend->str_img) > 0) { 
         int size;    
         guchar* buff = g_base64_decode(friend->str_img, &size);    
+
         GdkPixbufLoader* pbloader = gdk_pixbuf_loader_new_with_type ("jpeg", NULL);
         gdk_pixbuf_loader_write(pbloader, buff, size, NULL);
-	    GdkPixbuf* pixbuff_prev = gdk_pixbuf_loader_get_pixbuf(pbloader);
+	GdkPixbuf* pixbuff_prev = gdk_pixbuf_loader_get_pixbuf(pbloader);
+        g_free(buff);
+	gdk_pixbuf_loader_close(pbloader, NULL);
+
         int width = MIN_WIDTH_PHOTO;
         int height = gdk_pixbuf_get_height(pixbuff_prev) * MIN_WIDTH_PHOTO / gdk_pixbuf_get_width(pixbuff_prev);
         GdkPixbuf* pixbuff = gdk_pixbuf_scale_simple (pixbuff_prev, width, height, GDK_INTERP_BILINEAR);
         height = gdk_pixbuf_get_height(pixbuff);
+        g_object_unref(pixbuff_prev);
+
         GdkPixbuf* pixbuffsquare = gdk_pixbuf_new(gdk_pixbuf_get_colorspace(pixbuff), FALSE, gdk_pixbuf_get_bits_per_sample(pixbuff), width, height);
         gdk_pixbuf_copy_area(pixbuff, 0, 0, gdk_pixbuf_get_width(pixbuff), height, pixbuffsquare, 0, 0);
         image = gtk_image_new_from_pixbuf(pixbuffsquare);    
-        g_free(buff);
         g_object_unref(pixbuff);
-        g_object_unref(pixbuff_prev);
         g_object_unref(pixbuffsquare);
-	    gdk_pixbuf_loader_close(pbloader, NULL);
     } else {
         image = gtk_image_new_from_file(IMG_CONT);
         gpointer obj = (gpointer)image;
@@ -489,9 +526,10 @@ gpointer ui_friend(gpointer ptr_friend)
         xmlXPathObject *Obj;
         Obj = xpath(REQUEST_PARAMS_TAG_XPATH, img_req);
         xmlNodePtr node_params = Obj->nodesetval->nodeTab[0];
+        xmlXPathFreeObject(Obj);
         xmlNodePtr node_img;
-        node_img = xmlNewNode(NULL, "img");
-        xmlSetProp(node_img, "uri", friend->str_uri);
+        node_img = xmlNewNode(NULL, BAD_CAST "img");
+        xmlSetProp(node_img, BAD_CAST "uri", friend->str_uri);
         xmlAddChild(node_params, node_img);
         kernel->send(img_req, NULL, NULL);
         //hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
@@ -510,7 +548,8 @@ gpointer ui_friend(gpointer ptr_friend)
     ptr_str_id = g_strdup(friend->str_id);
     g_signal_connect(G_OBJECT(button_prf), "clicked", G_CALLBACK(callback_friend), (gpointer)ptr_str_id);
     g_signal_connect(G_OBJECT(button_msg), "clicked", G_CALLBACK(callback_friend_send_message), (gpointer)ptr_str_id);
-    
+    //FIXME
+    // free ptr_str_id ???
     return hbox;
 }
 
@@ -532,8 +571,8 @@ gboolean ui_driver_get_friends_profile(gpointer request)
     xmlNodePtr cont;
     gchar* date_birth;
 
-    g_source_destroy(ui_data->source_time);
-    g_source_unref(ui_data->source_time);
+    //g_source_destroy(ui_data->source_time);
+    //g_source_unref(ui_data->source_time);
    
     xmlXPathObject* obj = xpath("//TransitData/Content/Response/Params", request);
   
@@ -553,20 +592,29 @@ gboolean ui_driver_get_friends_profile(gpointer request)
     int i = 0;
     GtkWidget* detail;
     GtkWidget* label;
-    
+    gchar* str_detail;
+    gchar* str_prop;
+    gchar* str_content;    
+
     while(node != NULL)
     {
         gchar* type = (gchar*)node->name;
         if (!strcmp(type, TYPE_STRNG)) {
-            label = ui_init_label(xmlGetProp(node, "name"));
-            detail = gtk_label_new((gchar*)xmlNodeGetContent(node));
+            label = ui_init_label(_(xmlGetProp(node, "name")));
+            str_detail = (gchar*)xmlNodeGetContent(node);
+            detail = gtk_label_new(_(str_detail));
+            g_free(str_detail);
             GtkWidget* alignment_detail = gtk_alignment_new(0, 0.5, 0, 0);
             gtk_container_add(GTK_CONTAINER(alignment_detail), detail);
             gtk_box_pack_start (GTK_BOX (vbox_left), label, FALSE, FALSE, 0);        
             gtk_box_pack_start (GTK_BOX (vbox_right), alignment_detail, FALSE, FALSE, 0); 
-        } else if (!strcmp(type, TYPE_DATE) && strcmp((gchar*)xmlNodeGetContent(node), "00.00.0")) {
-            label = ui_init_label(xmlGetProp(node, "name"));
-            detail = gtk_label_new((gchar*)xmlNodeGetContent(node));
+        } else if (!strcmp(type, TYPE_DATE) && 
+                    (strcmp((gchar*)xmlNodeGetContent(node), "00.00") ||
+                     strcmp((gchar*)xmlNodeGetContent(node), "00.00.0"))) {
+            label = ui_init_label(_(xmlGetProp(node, "name")));
+            str_detail = (gchar*)xmlNodeGetContent(node);
+            detail = gtk_label_new(str_detail);
+            g_free(str_detail);
             GtkWidget* alignment_detail = gtk_alignment_new(0, 0.5, 0, 0);
             gtk_container_add(GTK_CONTAINER(alignment_detail), detail);
             gtk_box_pack_start (GTK_BOX (vbox_left), label, FALSE, FALSE, 0);        
@@ -574,18 +622,22 @@ gboolean ui_driver_get_friends_profile(gpointer request)
         } else if (!strcmp(type, TYPE_IMAGE)) {
             cont = node;
         } else if (!strcmp(type, TYPE_SELCT)) {
-            label = ui_init_label(xmlGetProp(node, "name"));
+            label = ui_init_label(_(xmlGetProp(node, "name")));
             gtk_box_pack_start (GTK_BOX (vbox_left), label, TRUE, TRUE, 0);  
             xmlNodePtr select = node->children;
             int i = 0;
             int n = 0;
             while (select != NULL) {
-                if (!strcmp(xmlGetProp(select, "selected"), "1")) {
-                    detail = gtk_label_new((gchar*)xmlNodeGetContent(select));
+                str_prop = xmlGetProp(select, "selected");
+                if (!strcmp(str_prop, "1")) {
+                    str_content = (gchar*)xmlNodeGetContent(select);
+                    detail = gtk_label_new(_(str_content));
+                    g_free(str_content);
                     GtkWidget* alignment_detail = gtk_alignment_new(0, 0.5, 0, 0);
                     gtk_container_add(GTK_CONTAINER(alignment_detail), detail);
                     gtk_box_pack_start (GTK_BOX (vbox_right), alignment_detail, FALSE, FALSE, PADDING);
                 }
+                g_free(str_prop);
                 select = select->next;                
                 i++;
             }            
@@ -596,7 +648,10 @@ gboolean ui_driver_get_friends_profile(gpointer request)
     guchar* buff; 
     GdkPixbuf* pixbuff;  
     int size;    
-    buff = g_base64_decode((gchar*)xmlNodeGetContent(cont), &size);    
+    gchar* node_content;
+    node_content = (gchar*)xmlNodeGetContent(cont);
+    buff = g_base64_decode(node_content, &size);
+    g_free(node_content);
     GdkPixbufLoader* pbloader;
     pbloader = gdk_pixbuf_loader_new_with_type ("jpeg", NULL);
     gdk_pixbuf_loader_write(pbloader, buff, size, NULL);
@@ -614,6 +669,7 @@ gboolean ui_driver_get_friends_profile(gpointer request)
     }        
     GtkWidget* image = gtk_image_new_from_pixbuf (pixbuff);
     g_object_unref(pixbuff);
+    //g_object_unref(pbloader);
     g_free(buff);
 
     
@@ -678,6 +734,8 @@ gboolean ui_driver_get_messages(gpointer request)
     } else {
         gtk_widget_set_sensitive(GTK_WIDGET(ui_data->button_messages_page_next), TRUE);
     }
+
+    xmlXPathFreeObject(Obj);
     
     Obj = xpath(PARAMS_TAG_XPATH, request);
   
@@ -696,27 +754,43 @@ gboolean ui_driver_get_messages(gpointer request)
 	hildon_pannable_area_add_with_viewport (panarea, vbox_messages);
     
     GtkWidget* message;
-    GtkWidget* separator;
-    gchar* xpath_req;
+    //GtkWidget* separator;
+    //gchar* xpath_req;
     //int n = 0;   
-    
+    gchar* node_name;
     for (node = node_root; node != NULL; node = node->next) {
         msg = g_new0(Message, 1);
         //xpath_req = g_strconcat(PARAMS_TAG_XPATH, "/struct[@='",xmlGetProp(node, "id"),"']",NULL);    
         //Obj = xpath(xpath_req, request);
         //child = Obj->nodesetval->nodeTab[0];
         for (child = node->children; child != NULL; child = child->next) {
-            if (!strcmp(xmlGetProp(child, "name"), "SenderId"))
+            node_name = xmlGetProp(child, "name");
+            if (!strcmp(node_name, "SenderId"))
                 msg->str_sender_id = xmlNodeGetContent(child);
-            if (!strcmp(xmlGetProp(child, "name"), "SenderName"))
+            
+            g_free(node_name);
+            node_name = xmlGetProp(child, "name");
+            if (!strcmp(node_name, "SenderName"))
                 msg->str_sender_name = xmlNodeGetContent(child);
-            if (!strcmp(xmlGetProp(child, "name"), "RecipientId"))
+            
+            g_free(node_name);
+            node_name = xmlGetProp(child, "name");
+            if (!strcmp(node_name, "RecipientId"))
                 msg->str_recipient_id = xmlNodeGetContent(child);
-            if (!strcmp(xmlGetProp(child, "name"), "RecipientName"))
+            
+            g_free(node_name);
+            node_name = xmlGetProp(child, "name");
+            if (!strcmp(node_name, "RecipientName"))
                 msg->str_recipient_name = xmlNodeGetContent(child);
-            if (!strcmp(xmlGetProp(child, "name"), "Time"))
+            
+            g_free(node_name);
+            node_name = xmlGetProp(child, "name");
+            if (!strcmp(node_name, "Time"))
                 msg->str_time = xmlNodeGetContent(child);
-            if (!strcmp(xmlGetProp(child, "name"), "Text")) {
+            
+            g_free(node_name);
+            node_name = xmlGetProp(child, "name");
+            if (!strcmp(node_name, "Text")) {
         	gchar *child_text = xmlNodeGetContent(child);
                 msg->str_text = g_strcompress (child_text);
                 g_free(child_text);
@@ -724,11 +798,18 @@ gboolean ui_driver_get_messages(gpointer request)
                 msg->str_text = g_markup_escape_text(child_text, strlen(child_text));
                 g_free(child_text);
             }
-            if (!strcmp(xmlGetProp(child, "name"), "Status"))
+        
+            g_free(node_name);
+            node_name = xmlGetProp(child, "name");
+            if (!strcmp(node_name, "Status"))
                 msg->str_status = xmlNodeGetContent(child);
+            g_free(node_name);
         }
         //if (n < 1) {
             message = ui_message((gpointer)msg);
+//FIXME
+// FREE stuct msg
+            
             gtk_box_pack_start (GTK_BOX (vbox_messages), message, FALSE, TRUE, 0);
             //n++;
         //}
@@ -737,12 +818,14 @@ gboolean ui_driver_get_messages(gpointer request)
     if (to > ui_data->num_msgs) {
         to = ui_data->num_msgs;
     }
-    gtk_label_set_text(GTK_LABEL(ui_data->label_messages_page), g_strdup_printf("%d - %d", from + 1, to));
+    gchar* str_from_to;
+    str_from_to = g_strdup_printf("%d - %d / %d", from + 1, to, ui_data->num_msgs);
+    gtk_label_set_text(GTK_LABEL(ui_data->label_messages_page), str_from_to);
     gtk_box_pack_start (GTK_BOX (ui_data->box_messages_list), panarea, TRUE, TRUE, PADDING); 
     gtk_widget_show_all(ui_data->box_messages_list);
     
-    // Kulakov: remove because valgrind says that it's already freed.
-    //xmlXPathFreeObject(Obj);
+    g_free(str_from_to);
+    xmlXPathFreeObject(Obj);
     xmlFreeDoc(request);
     return FALSE; 
 }
@@ -759,13 +842,18 @@ gpointer ui_message(gpointer msg_pointer)
     GtkWidget* container = hildon_button_new(HILDON_SIZE_THUMB_HEIGHT, NULL);
     mbox type;
     GtkWidget* label_name = gtk_label_new(NULL);
+    gchar* str_markup;
+
     if (strlen(msg->str_sender_name) > 0) {
         type = INBOX;
-        gtk_label_set_markup(GTK_LABEL(label_name), g_strconcat(MARKUP, STR_FROM, PUKRAM, msg->str_sender_name, NULL));
+        str_markup = g_strconcat(MARKUP, STR_FROM, PUKRAM, msg->str_sender_name, NULL);
     } else  if (strlen(msg->str_recipient_name) > 0) {
         type = SENT;
-        gtk_label_set_markup(GTK_LABEL(label_name), g_strconcat(MARKUP, STR_TO, PUKRAM, msg->str_recipient_name, NULL));
+        str_markup = g_strconcat(MARKUP, STR_TO, PUKRAM, msg->str_recipient_name, NULL);
     }
+    gtk_label_set_markup(GTK_LABEL(label_name), str_markup);
+    g_free(str_markup);
+
     //GtkWidget* label_spac = gtk_label_new(" ");
     GtkWidget* label_time = gtk_label_new(NULL);
     
@@ -780,14 +868,20 @@ gpointer ui_message(gpointer msg_pointer)
 // !!!    
     g_free(msg->str_time);    
     msg->str_time = str_time;
-    gtk_label_set_markup(GTK_LABEL(label_time), g_strconcat(MARKUP, " ", str_date, "  ", str_time, PUKRAM, NULL));
+    str_markup = g_strconcat(MARKUP, " ", str_date, "  ", str_time, PUKRAM, NULL);
+    gtk_label_set_markup(GTK_LABEL(label_time), str_markup);
+    g_free(str_markup);
+
     GtkWidget* label_text = gtk_label_new(NULL);
     
     if (!strcmp(msg->str_status, "0")){
-        gtk_label_set_markup(GTK_LABEL(label_text), g_strconcat(MARKUP_UNREAD, msg->str_text, PUKRAM, NULL));
+        str_markup = g_strconcat(MARKUP_UNREAD, msg->str_text, PUKRAM, NULL);
     } else {
-        gtk_label_set_markup(GTK_LABEL(label_text), g_strconcat(MARKUP_READ, msg->str_text, PUKRAM, NULL));   
+        str_markup = g_strconcat(MARKUP_READ, msg->str_text, PUKRAM, NULL);
     }
+    gtk_label_set_markup(GTK_LABEL(label_text), str_markup);
+    g_free(str_markup);
+
     gtk_label_set_line_wrap(GTK_LABEL(label_text), TRUE);
     gtk_label_set_single_line_mode(GTK_LABEL(label_text), FALSE);
     gtk_label_set_ellipsize(GTK_LABEL(label_text), PANGO_ELLIPSIZE_END);
@@ -811,7 +905,8 @@ gpointer ui_message(gpointer msg_pointer)
     if (type == INBOX) {
         g_signal_connect(G_OBJECT(container), "clicked", G_CALLBACK(callback_message_reply), (gpointer)msg);
     } else {
-        g_signal_connect(G_OBJECT(container), "clicked", G_CALLBACK(callback_empty), msg_pointer);
+        g_signal_connect(G_OBJECT(container), "clicked", G_CALLBACK(callback_message_reply), (gpointer)msg);
+        //g_signal_connect(G_OBJECT(container), "clicked", G_CALLBACK(callback_empty), msg_pointer);
     }
     gtk_widget_show_all(container);
     return container;
@@ -1050,6 +1145,7 @@ gboolean ui_show_info(gpointer request)
     }
     //hildon_gtk_window_set_progress_indicator (ui_data->window, 0);
     g_free(code);
+    g_free(text);
     xmlFreeDoc(request);
     return FALSE;    
 }
@@ -1061,8 +1157,8 @@ gboolean ui_show_info(gpointer request)
 **/
 gboolean ui_show_error(gpointer request)
 {
-    g_source_destroy(ui_data->source_time);
-    g_source_unref(ui_data->source_time);
+    //g_source_destroy(ui_data->source_time);
+    //g_source_unref(ui_data->source_time);
     gboolean show = TRUE;
     gchar* text;
     gchar* code;
@@ -1071,13 +1167,16 @@ gboolean ui_show_error(gpointer request)
      
     if (obj != NULL && obj->nodesetval->nodeNr != 0) {
         text = xmlNodeGetContent(obj->nodesetval->nodeTab[0]);
+        xmlXPathFreeObject(obj);
     }
     else {
         return FALSE;
     }
+
     obj = xpath("//TransitData/Content/Response/Params/string[@name='code']", request);
     if (obj->nodesetval->nodeNr != 0) {
         code = xmlNodeGetContent(obj->nodesetval->nodeTab[0]);
+        xmlXPathFreeObject(obj);
     }
     
     g_print("\n##################\n#                #\n#   ERROR: %s   #\n#                #\n##################\n", code);
@@ -1085,15 +1184,41 @@ gboolean ui_show_error(gpointer request)
     if(strcmp(code, DB_GET_ERROR_FRIENDS_CODE) == 0) {
         show = FALSE;
         gtk_label_set_text(GTK_LABEL(ui_data->label_friends_page), STR_EMPT);
+        GList* children = gtk_container_get_children (GTK_CONTAINER(ui_data->box_friends_list));
+        for (; children != NULL; children = children->next){
+            gtk_widget_destroy(children->data); 
+        }
+        gtk_widget_hide(ui_data->box_friends_navi);
         callback_button_friends_update(NULL, NULL);
     }
+    if(strcmp(code, DB_ERROR_SEARCH_FRIENDS_CODE) == 0) {
+        show = FALSE;
+        GList* children = gtk_container_get_children (GTK_CONTAINER(ui_data->box_friends_list));
+        for (; children != NULL; children = children->next){
+            gtk_widget_destroy(children->data); 
+        }
+        //gtk_box_pack_start(GTK_BOX(ui_data->box_friends_list), gtk_label_new(ui_data->friends_filter ? STR_NOSR : STR_NOON), TRUE, TRUE, 0);
+        gtk_box_pack_start(GTK_BOX(ui_data->box_friends_list), gtk_label_new(STR_NOSR), TRUE, TRUE, 0);
+        gtk_widget_show_all(GTK_WIDGET(ui_data->box_friends_list));
+        gtk_widget_hide(ui_data->box_friends_navi);
+    }
     if(strcmp(code, DB_GET_ERROR_PROFILE_CODE) == 0){
         show = FALSE;
         callback_button_profile_update(NULL, NULL);
     }
     if(strcmp(code, DB_GET_ERROR_INBOX_MESSAGES_CODE) == 0 || strcmp(code, DB_GET_ERROR_OUTBOX_MESSAGES_CODE) == 0){
         show = FALSE;
-        callback_button_messages_update(NULL, NULL);
+        if (ui_data->empty_messages){
+            callback_button_messages_update(NULL, NULL);
+            ui_data->empty_messages = FALSE;   
+        } else {
+            GList* children = gtk_container_get_children (GTK_CONTAINER(ui_data->box_messages_list));
+            for (; children != NULL; children = children->next){
+                gtk_widget_destroy(children->data);
+            }
+            gtk_box_pack_start(GTK_BOX(ui_data->box_messages_list), gtk_label_new(STR_NOMS), TRUE, TRUE, 0);
+            gtk_widget_show_all(GTK_WIDGET(ui_data->box_messages_list));
+        }
     }
     if(strcmp(code, DB_SAVE_ERROR_FRIENDS_PROFILE_CODE) == 0){
         show = FALSE;
@@ -1105,8 +1230,9 @@ gboolean ui_show_error(gpointer request)
     if(show)
         hildon_banner_show_information(ui_data->window, NULL, text);
     //hildon_gtk_window_set_progress_indicator (ui_data->window, 0);
-    xmlXPathFreeObject(obj);
     xmlFreeDoc(request);
+    g_free(code);
+    g_free(text);
 
     return FALSE;
 }
@@ -1272,27 +1398,33 @@ gboolean ui_show_img(gpointer request)
         s_img = xmlNodeGetContent(node_bin);
 
         buff = g_base64_decode(s_img, &size);    
+        g_free(s_img);
         GdkPixbufLoader* pbloader;
         pbloader = gdk_pixbuf_loader_new_with_type ("jpeg", NULL);
         gdk_pixbuf_loader_write(pbloader, buff, size, NULL);
+        GdkPixbuf *pixbuff_orig = gdk_pixbuf_loader_get_pixbuf(pbloader);
         gdk_pixbuf_loader_close (pbloader, NULL);
+        g_free(buff);
+
         width = MIN_WIDTH_PHOTO;
-        height = gdk_pixbuf_get_height(gdk_pixbuf_loader_get_pixbuf(pbloader)) * MIN_WIDTH_PHOTO / gdk_pixbuf_get_width(gdk_pixbuf_loader_get_pixbuf(pbloader));
-        GdkPixbuf* pixbuff = gdk_pixbuf_scale_simple (gdk_pixbuf_loader_get_pixbuf(pbloader), width, height, GDK_INTERP_BILINEAR);
+        height = gdk_pixbuf_get_height(pixbuff_orig) * MIN_WIDTH_PHOTO / gdk_pixbuf_get_width(pixbuff_orig);
+        GdkPixbuf* pixbuff = gdk_pixbuf_scale_simple (pixbuff_orig, width, height, GDK_INTERP_BILINEAR);
+        g_object_unref(pixbuff_orig);
         height = gdk_pixbuf_get_height(pixbuff);
         if (gdk_pixbuf_get_height(pixbuff) > gdk_pixbuf_get_width(pixbuff)) {
             height = gdk_pixbuf_get_width(pixbuff);
         }
+
         GdkPixbuf* pixbuffsquare = gdk_pixbuf_new(gdk_pixbuf_get_colorspace(pixbuff), FALSE, gdk_pixbuf_get_bits_per_sample(pixbuff), gdk_pixbuf_get_width(pixbuff), height);
         gdk_pixbuf_copy_area(pixbuff, 0, 0, gdk_pixbuf_get_width(pixbuff), height, pixbuffsquare, 0, 0);
         gpointer value = g_hash_table_lookup(ui_data->table_imgs, (gpointer)s_uri);
         //g_print("\n\n\n!!! S_URI: %s !!!\n\n\n!!! WIDGET IS: %s !!!\n\n\n", s_uri, gtk_widget_get_name(GTK_WIDGET(value)));
         gtk_image_set_from_pixbuf ((GtkImage*)value, pixbuffsquare);
-        //g_free(buff);
-        //g_object_unref(pixbuff);
-        //g_object_unref(pixbuffsquare);
+        g_object_unref(pixbuff);
+        g_object_unref(pixbuffsquare);
+        g_free(s_uri);
         //g_free(pbloader);
-        //g_object_unref(pbloader); 
+        //g_object_unref(pbloader);
     }
     xmlXPathFreeObject(obj);
     xmlFreeDoc(request);
