@@ -25,7 +25,9 @@
 
 #include <glib/gprintf.h>
 #include <glib.h>
+#include <mysocials_driver.h>
 #include "ui_general.h"
+#include "ui_strings.h"
 #include "../msa_module.h"
 
 extern int msa_module_init(msa_module*);
