@@ -149,6 +149,7 @@ void callback_combo_changed(GtkComboBox* widget, gpointer user_data)
     //g_print("%s\n", gtk_combo_box_get_active_text(GTK_COMBO_BOX(widget)));
     
     gchar *obj_path = g_strconcat("//TransitData/Content/Response/Params/select[@name='", (gchar*)user_data,"']", NULL);
+
     xmlXPathObject* obj = xpath(obj_path, ui_data->ui_request);
     g_free(obj_path);
     //g_print("\n\n\n!!!!! %s !!!!!\n\n\n%d\n\n\n", hildon_button_get_value (widget), hildon_picker_button_get_active(widget));
@@ -182,17 +183,16 @@ void callback_date_edit(GtkWidget* button, gpointer value)
     date.tm_mday = d;
     date.tm_mon = m;
     date.tm_year = y - 1900;
-    gchar* str_date = g_malloc(sizeof(gchar) * 11);
-    strftime(str_date, 11, "%d.%m.%Y\0", &date);
+    gchar str_date[20] = {0};
+    strftime(str_date, 19, "%d.%m.%Y", &date);
     hildon_button_set_value(button, str_date);
-    //xmlXPathObject* obj = xpath("//TransitData/Content/Response/Params/date[@name='Birthday']", ui_data->ui_request);
-    //g_print("\n\n\n\t!!! %s !!!\n\n\n", str_date);
-    //if (obj != NULL && obj->nodesetval->nodeNr != 0) {
-    //    g_debug("!!!!");
-    //    xmlNodeSetContent(obj->nodesetval->nodeTab[0], str_date);
-    //}
-    //g_print("\n\ndate is set\n\n");
-    g_free(str_date);
+    xmlXPathObject* obj = xpath("//TransitData/Content/Response/Params/date[@name='Birthday']", ui_data->ui_request);
+    g_print("\n\n\n\t!!! %s !!!\n\n\n", str_date);
+    if (obj != NULL && obj->nodesetval->nodeNr != 0) {
+        g_debug("!!!!");
+        xmlNodeSetContent(obj->nodesetval->nodeTab[0], BAD_CAST str_date);
+    }
+    g_print("\n\ndate is set\n\n");
 }
 
 /**
@@ -239,6 +239,7 @@ void callback_button_friends_get(GtkWidget* button, gpointer data)
     //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     int from = FRIENDS_PER_PAGE*ui_data->page_frds;
     int to = FRIENDS_PER_PAGE*(ui_data->page_frds + 1);
+    int online = ui_data->friends_offline ? 0 : 1;
     gchar* str_sort;
     if(ui_data->ascending) {
         str_sort = g_strdup("asc");
@@ -258,10 +259,8 @@ void callback_button_friends_get(GtkWidget* button, gpointer data)
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
     <Content><Request class=\"friends\" function = \"getListFriends\"><Params From=\"", sfrom,
-    "\" To=\"", sto, "\" Sort=\"", str_sort, "\"/></Request></Content></TransitData>", NULL);
-    xmlDocPtr resp = NULL;
-    kernel->send(xmlParseDoc(request), &resp, NULL);
-    xmlFreeDoc(resp);
+    "\" To=\"", sto, "\" Sort=\"", str_sort, "\" Online=\"",g_strdup_printf("%d", online),"\"/></Request></Content></TransitData>", NULL);
+    kernel->send(xmlParseDoc(request), NULL, NULL);
     g_free(request);
     g_free(sfrom);
     g_free(str_sort);
@@ -299,10 +298,12 @@ void callback_friends_filter(gchar* str_filter)
     
     if (ui_data->friends_filter) {
         gtk_widget_hide(ui_data->box_friends_navi);
+        gtk_widget_hide(ui_data->button_friends_show_offl);        
         gtk_label_set_text(GTK_LABEL(ui_data->label_friends_filter), g_strconcat(STR_RSLT, " \"", str_filter, "\"", NULL));
         gtk_widget_show_all(ui_data->box_friends_result);
     } else {
         gtk_widget_show_all(ui_data->box_friends_navi);
+        gtk_widget_show(ui_data->button_friends_show_offl); 
         gtk_widget_hide(ui_data->box_friends_result);
     }
 }
@@ -452,6 +453,21 @@ void callback_message_reply(GtkWidget* container, gpointer data)
     return;
 }
 
+/**
+ * @brief view sent message
+ * @param
+ * @return
+**/
+void callback_message_another(GtkWidget* container, gpointer data)
+{
+    Message* msg = data;
+    GtkWidget* window_msg = hildon_stackable_window_new();
+    gtk_window_set_title(GTK_WINDOW(window_msg), STR_PROG);
+    gtk_container_add(GTK_CONTAINER((GtkWidget*)window_msg), ui_init_message_reply(data));
+    gtk_widget_show(GTK_WIDGET(window_msg));
+    return;
+}
+
 /**
  * @brief show reply entry
  * @param
@@ -540,10 +556,12 @@ void callback_button_msgs(GtkWidget* widget, gpointer user_data)
     ui_data->page_msgs = 0;
     if ((int)user_data == 0 && ui_data->msgs_box != INBOX) {
         ui_data->msgs_box = INBOX;
+        ui_data->empty_messages = TRUE;
         callback_button_messages_get(NULL, NULL);
     }
     if ((int)user_data == 1 && ui_data->msgs_box == INBOX) {
         ui_data->msgs_box = SENT;
+        ui_data->empty_messages = TRUE;
         callback_button_messages_get(NULL, NULL);
     }
 }
@@ -834,6 +852,18 @@ void callback_friends_join(GtkWidget* button_cb, gpointer data)
     gtk_widget_destroy( GTK_WIDGET( dialog ) );
 }
 
+/** @brief show / hide offline
+  * @param 
+**/
+void callback_button_friends_show_offline(GtkWidget* button, gpointer data)
+{
+    if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)) != ui_data->friends_offline) {
+        ui_data->friends_offline = !ui_data->friends_offline;
+        ui_data->page_frds = 0;
+        callback_button_friends_get(NULL, NULL);
+    }
+}
+
 /**
  * @brief find friends
  * @param req - xpath req
@@ -862,6 +892,13 @@ void callback_button_friends_find(GtkWidget* button_cb, gpointer data)
     result = gtk_dialog_run(dialog);
     if(result == GTK_RESPONSE_ACCEPT) {
         gchar* str = gtk_entry_get_text(GTK_ENTRY(entry));
+
+        if (strlen(str) > 0) {
+            callback_friends_filter(str);
+        } else {
+            callback_friends_filter(NULL);
+        }
+        
         gchar *request = g_strconcat("<?xml version=\"1.0\"?><TransitData id=\"1\" \
         type=\"data\"><SourceID>ui</SourceID>\
         <TargetID>db</TargetID>\
@@ -1181,6 +1218,8 @@ void callback_button_save_setup_service(GtkWidget* button, gpointer id)
     GList* node;
     int i = 0;
     msa_module* info;
+    gchar* str_request;
+    gchar* str_autoupdate;
     for(node = ui_data->drivers; node != NULL; node = node->next) {
         if (i == ui_data->srvc){
             info = (msa_module*)node->data;
@@ -1188,8 +1227,20 @@ void callback_button_save_setup_service(GtkWidget* button, gpointer id)
             actv = g_strdup("1");
             info->status = ON;
             info->state = CONF;
-            //hildon_gtk_window_set_progress_indicator(ui_data->window, 1); 
-            kernel->msa_settings(info->id, xmlParseDoc(g_strconcat("<?xml version=\"1.0\"?><TransitData><SourceID>ui</SourceID><TargetID>",info->id,"</TargetID><Content><Request class=\"settings\" function=\"setSettings\"><Params><string name=\"login\">",gtk_entry_get_text(GTK_LABEL(ui_data->entry_logn)),"</string><string name=\"password\">",gtk_entry_get_text(GTK_LABEL(ui_data->entry_pass)),"</string><number name=\"autoupdate\">",g_strdup_printf("%d",(hildon_number_editor_get_value(ui_data->entry_auto))),"</number><boolean name=\"active\">",actv,"</boolean></Params></Request></Content></TransitData>",NULL)));
+            //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
+            str_autoupdate = g_strdup_printf("%d",(hildon_number_editor_get_value(ui_data->entry_auto)));
+            str_request = g_strconcat("<?xml version=\"1.0\"?><TransitData><SourceID>ui</SourceID>\
+<TargetID>",info->id,"</TargetID>\
+<Content>\
+<Request class=\"settings\" function=\"setSettings\">\
+<Params>\
+<string name=\"login\">",gtk_entry_get_text(GTK_LABEL(ui_data->entry_logn)),"</string>\
+<string name=\"password\">",gtk_entry_get_text(GTK_LABEL(ui_data->entry_pass)),"</string>\
+<number name=\"autoupdate\">",str_autoupdate,"</number>\
+<boolean name=\"active\">",actv,"</boolean></Params></Request></Content></TransitData>",NULL);
+            kernel->msa_settings(info->id, xmlParseDoc(str_request));
+            g_free(str_autoupdate);
+            g_free(str_request);
             break;
         }
         i++;
@@ -1228,23 +1279,34 @@ void callback_empty(GtkWidget* widget, gpointer data)
 **/
 void callback_task_switch(GtkWidget* notebook, GtkNotebookPage* page, guint page_num, gpointer user_data)
 {
+    gchar* str_title;
     switch(page_num) {
     case 0:
         callback_button_profile_get(NULL, NULL);
-        gtk_window_set_title (GTK_WINDOW (ui_data->window), g_strconcat(STR_PROG, STR_TTLS, STR_PRFL, NULL));
+        str_title = g_strconcat(STR_PROG, STR_TTLS, STR_PRFL, NULL);
+        ui_data->empty_messages = TRUE;
         break;
     case 1:
         callback_button_friends_get(NULL, NULL);
-        gtk_window_set_title (GTK_WINDOW (ui_data->window), g_strconcat(STR_PROG, STR_TTLS, STR_FRDS, NULL));
+        str_title = g_strconcat(STR_PROG, STR_TTLS, STR_FRDS, NULL);
+        ui_data->empty_messages = TRUE;
         break;
     case 2:
-        callback_button_messages_get(NULL, NULL);
-        gtk_window_set_title (GTK_WINDOW (ui_data->window), g_strconcat(STR_PROG, STR_TTLS, STR_MSGS, NULL));
+        if (ui_data->empty_messages) {
+            callback_button_messages_update(NULL, NULL);
+            ui_data->empty_messages = FALSE;
+        } else {
+            callback_button_messages_get(NULL, NULL);
+        }
+        str_title = g_strconcat(STR_PROG, STR_TTLS, STR_MSGS, NULL);
         break;
     case 3:
-        gtk_window_set_title (GTK_WINDOW (ui_data->window), g_strconcat(STR_PROG, STR_TTLS, STR_SETS, NULL));
+        str_title = g_strconcat(STR_PROG, STR_TTLS, STR_SETS, NULL);
+        ui_data->empty_messages = TRUE;
         break;
     }
+    gtk_window_set_title (GTK_WINDOW (ui_data->window), str_title);
+    g_free(str_title);
 }
 
 /**
@@ -1268,4 +1330,4 @@ void callback_exit(GtkAction* action, gpointer data)
 {
     kernel->shutdown();
     gtk_main_quit();
-}
\ No newline at end of file
+}
