@@ -70,7 +70,9 @@ static void ui_init_tasks()
     /* PROFILE */ 
     ui_data->box_profile = gtk_hbox_new(FALSE, 0);
     GtkWidget* box_prfl = gtk_hbox_new(TRUE, 0);
-    GtkWidget* box_service = gtk_hbox_new(FALSE, 0);
+
+// !!!
+//    GtkWidget* box_service = gtk_hbox_new(FALSE, 0);
     GtkWidget* button_prfl_1 = GTK_WIDGET(ui_init_button_service());
     GtkWidget* button_prfl_2 = GTK_WIDGET(hildon_button_new_with_text(HILDON_SIZE_FINGER_HEIGHT, NULL, STR_UPDT, NULL));
     GtkWidget* button_prfl_3 = GTK_WIDGET(hildon_button_new_with_text(HILDON_SIZE_FINGER_HEIGHT, NULL, STR_SAVE, NULL));
@@ -83,19 +85,24 @@ static void ui_init_tasks()
     g_signal_connect(G_OBJECT(button_prfl_3), "clicked", G_CALLBACK(callback_button_profile_save), NULL);    
     /* FRIENDS */
     GtkWidget* box_friends_list = gtk_vbox_new(FALSE, 0);
+    GtkWidget* box_friends_tool = gtk_hbox_new(FALSE, 0);
     ui_data->box_friends_list = gtk_vbox_new(TRUE, 0);
     ui_data->box_friends = gtk_hbox_new(FALSE, 0);    
     ui_data->box_friend = gtk_vbox_new(FALSE, 0);    
     gtk_box_pack_start(GTK_BOX(box_friends_list), ui_data->box_friends_list, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(box_friends_list), gtk_hseparator_new(), FALSE, FALSE, 0);    
     gtk_box_pack_start(GTK_BOX(ui_data->taskboxes[1]), ui_data->box_friends, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(ui_data->box_friends), box_friends_list, TRUE, TRUE, PADDING);    
+    gtk_box_pack_start(GTK_BOX(ui_data->box_friends), box_friends_list, TRUE, TRUE, PADDING);
+    gtk_box_pack_start(GTK_BOX(box_friends_list), box_friends_tool, FALSE, TRUE, 0);
     ui_data->page_frds = 0;
-    ui_data->ascending = FALSE;        
+    ui_data->ascending = FALSE;
+    ui_data->friends_offline = FALSE;      
     /* FRIENDS NAVIGATION */
-    ui_data->box_friends_navi = gtk_hbox_new(FALSE, 0);    
-    gtk_box_pack_start (GTK_BOX(box_friends_list), ui_data->box_friends_navi, FALSE, TRUE, 0);
-    ui_data->label_friends_page = gtk_label_new(STR_EMPT);    
+    ui_data->box_friends_navi = gtk_hbox_new(FALSE, 0);
+    GtkWidget* box_friends_show_offl = gtk_vbox_new(FALSE, 0);
+    ui_data->label_friends_page = gtk_label_new(STR_EMPT);
+    ui_data->button_friends_show_offl = GTK_WIDGET(hildon_gtk_toggle_button_new(HILDON_SIZE_FINGER_HEIGHT)); 
+    gtk_toggle_button_set_active(GTK_BUTTON(ui_data->button_friends_show_offl), ui_data->friends_offline);
     ui_data->button_friends_page_prev = GTK_WIDGET(hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL));
     ui_data->button_friends_page_next = GTK_WIDGET(hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL));
     ui_data->button_friends_page_frst = GTK_WIDGET(hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL));
@@ -104,19 +111,24 @@ static void ui_init_tasks()
     gtk_button_set_relief(GTK_BUTTON(ui_data->button_friends_page_next), GTK_RELIEF_NONE);
     gtk_button_set_relief(GTK_BUTTON(ui_data->button_friends_page_frst), GTK_RELIEF_NONE);
     gtk_button_set_relief(GTK_BUTTON(ui_data->button_friends_page_last), GTK_RELIEF_NONE);
+    gtk_button_set_label (GTK_BUTTON(ui_data->button_friends_show_offl), STR_SHOW);
     hildon_button_set_image(ui_data->button_friends_page_prev, gtk_image_new_from_file(IMG_PREV));
     hildon_button_set_image(ui_data->button_friends_page_next, gtk_image_new_from_file(IMG_NEXT));
     hildon_button_set_image(ui_data->button_friends_page_frst, gtk_image_new_from_file(IMG_FRST));
     hildon_button_set_image(ui_data->button_friends_page_last, gtk_image_new_from_file(IMG_LAST));
+    gtk_box_pack_start(GTK_BOX(box_friends_show_offl), ui_data->button_friends_show_offl, TRUE, TRUE, 0); 
+    gtk_box_pack_start(GTK_BOX(box_friends_tool), box_friends_show_offl, TRUE, TRUE, 0); 
+    gtk_box_pack_start(GTK_BOX(box_friends_tool), ui_data->box_friends_navi, FALSE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_navi), ui_data->button_friends_page_frst, FALSE, FALSE, 0); 
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_navi), ui_data->button_friends_page_prev, FALSE, FALSE, 0); 
-    gtk_box_pack_start(GTK_BOX(ui_data->box_friends_navi), ui_data->label_friends_page, TRUE, FALSE, 0); 
+    gtk_box_pack_start(GTK_BOX(ui_data->box_friends_navi), ui_data->label_friends_page, TRUE, TRUE, 0); 
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_navi), ui_data->button_friends_page_next, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_navi), ui_data->button_friends_page_last, FALSE, FALSE, 0);    
     g_signal_connect(G_OBJECT(ui_data->button_friends_page_prev), "clicked", G_CALLBACK(callback_button_friends_page_prev), NULL);
     g_signal_connect(G_OBJECT(ui_data->button_friends_page_next), "clicked", G_CALLBACK(callback_button_friends_page_next), NULL);
     g_signal_connect(G_OBJECT(ui_data->button_friends_page_frst), "clicked", G_CALLBACK(callback_button_friends_page_frst), NULL);
     g_signal_connect(G_OBJECT(ui_data->button_friends_page_last), "clicked", G_CALLBACK(callback_button_friends_page_last), NULL);
+    g_signal_connect(G_OBJECT(ui_data->button_friends_show_offl), "clicked", G_CALLBACK(callback_button_friends_show_offline), NULL);
     /* FRIENDS FILTER */
     ui_data->box_friends_result = gtk_hbox_new(FALSE, PADDING);
     ui_data->label_friends_filter = gtk_label_new(NULL);
@@ -126,7 +138,7 @@ static void ui_init_tasks()
     gtk_container_add(GTK_CONTAINER(button_friends_result), gtk_image_new_from_file(IMG_CLER));
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_result), ui_data->label_friends_filter, TRUE, TRUE, 0); 
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_result), button_friends_result, FALSE, FALSE, 0); 
-    gtk_box_pack_start(GTK_BOX(box_friends_list), ui_data->box_friends_result, FALSE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box_friends_tool), ui_data->box_friends_result, FALSE, TRUE, 0);
     /* FRIENDS TASKS */
     GtkWidget* box_friends_tasks = gtk_vbox_new(TRUE, 0);
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends), box_friends_tasks, FALSE, TRUE, 0);
@@ -166,6 +178,7 @@ static void ui_init_tasks()
     ui_data->box_messages = box_msgs;
     ui_data->msgs_box = INBOX;
     ui_data->page_msgs = 0;
+    ui_data->empty_messages = TRUE;
     gtk_widget_set_sensitive(GTK_WIDGET(button_msgs_find), FALSE);
     gtk_widget_set_sensitive(GTK_WIDGET(button_msgs_comp), FALSE);
     gtk_widget_set_sensitive(GTK_WIDGET(button_msgs_from), FALSE);    
@@ -242,10 +255,10 @@ void ui_init_driver_settings(gpointer data)
     int i;
     gtk_box_pack_start (GTK_BOX (ui_data->box_setting), vbox_left, FALSE, TRUE, PADDING);
     gtk_box_pack_start (GTK_BOX (ui_data->box_setting), vbox_edit, TRUE, TRUE, 0);
-    labels[0] = gtk_label_new(_("Login:"));
-    labels[1] = gtk_label_new(_("Password:"));
-    labels[2] = gtk_label_new(_("Auto-update time:"));
-    labels[3] = gtk_label_new(_("second(s)"));
+    labels[0] = gtk_label_new(STR_LOGIN);
+    labels[1] = gtk_label_new(STR_PASSWORD);
+    labels[2] = gtk_label_new(STR_AUTOUPDATE);
+    labels[3] = gtk_label_new(STR_SECONDS);
     gtk_misc_set_alignment(GTK_MISC(labels[0]), 1, 0.5);
     gtk_misc_set_alignment(GTK_MISC(labels[1]), 1, 0.5);
     gtk_misc_set_alignment(GTK_MISC(labels[2]), 1, 0.5);
@@ -365,7 +378,10 @@ void ui_init_help()
     GtkWidget* window_help = GTK_WIDGET(hildon_stackable_window_new());
     gtk_window_set_title (GTK_WINDOW (window_help), STR_HELP);
     /* label */
-    GtkWidget* label = gtk_label_new(STR_HELPT);
+    
+    gchar *str = g_strdup_printf(STR_HELPT, VERSION);
+    GtkWidget* label = gtk_label_new(str);
+    g_free(str);
 	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
 	gtk_label_set_single_line_mode(GTK_LABEL(label), FALSE);
 	/* pannable area */
@@ -386,7 +402,9 @@ void ui_init_bout()
     GtkWidget* window_bout = hildon_stackable_window_new();
     gtk_window_set_title (GTK_WINDOW (window_bout), STR_BOUT);
     /* label */
-    GtkWidget* label = gtk_label_new(STR_ABOUT);    
+    gchar *str = g_strdup_printf(STR_ABOUT, VERSION);
+    GtkWidget* label = gtk_label_new(str);
+    g_free(str);
 	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
 	gtk_label_set_single_line_mode(GTK_LABEL(label), FALSE);
     /* pannable area */
@@ -455,15 +473,19 @@ gpointer ui_init_friend_tools(gpointer ptr_str_id)
     GtkWidget* box = gtk_hbox_new(TRUE, 0);
     GtkWidget* button_srvc = ui_init_button_service();
     GtkWidget* button_updt = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
+    GtkWidget* button_nmsg = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
     GtkWidget* button_join = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
     ui_data->button_friend_profile_refresh = button_updt;
     hildon_button_set_title(button_updt, STR_UPDT);
     hildon_button_set_title(button_join, STR_JOIN);
+    hildon_button_set_title(button_nmsg, STR_NMSG);
     gtk_widget_set_sensitive(GTK_WIDGET(button_join), FALSE);
     gtk_box_pack_start(GTK_BOX(box), button_srvc, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(box), button_updt, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box), button_nmsg, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(box), button_join, TRUE, TRUE, 0);
     g_signal_connect(G_OBJECT(button_updt), "clicked", G_CALLBACK(callback_button_friends_profile_update), ptr_str_id);
+    g_signal_connect(G_OBJECT(button_nmsg), "clicked", G_CALLBACK(callback_friend_send_message), ptr_str_id);
     g_signal_connect(G_OBJECT(button_join), "clicked", G_CALLBACK(callback_button_friends_profile_join), ptr_str_id);
     return box;    
 }
@@ -477,12 +499,22 @@ gpointer ui_init_message_reply(gpointer ptr_msg)
 {
     Message* msg = ptr_msg;
     Friend* friend = struct_friend_create();
-    friend->str_id = msg->str_sender_id;
     GtkWidget* box = gtk_hbox_new(FALSE, 0);
     GtkWidget* container = gtk_vbox_new(FALSE, 0);
     GtkWidget* box_reply = gtk_vbox_new(FALSE, 0);
     GtkWidget* hbox_header = gtk_hbox_new(FALSE, 0);
-    GtkWidget* label_sndr = gtk_label_new(STR_FROM);
+    GtkWidget* label_sndr;
+    
+    if (msg->str_recipient_name == NULL || strcmp(msg->str_recipient_name, "") == 0) {
+        label_sndr = gtk_label_new(STR_FROM);
+        friend->str_id = msg->str_sender_id;
+        friend->str_name = msg->str_sender_name;
+    } else {
+        label_sndr = gtk_label_new(STR_TO);
+        friend->str_id = msg->str_recipient_id;
+        friend->str_name = msg->str_recipient_name;
+    }
+    
     GtkWidget* label_time = gtk_label_new(g_strconcat(msg->str_date, "  ", msg->str_time, NULL));
     GtkWidget* label_text = gtk_label_new(NULL);
     GtkWidget* button_rply = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
@@ -499,10 +531,16 @@ gpointer ui_init_message_reply(gpointer ptr_msg)
     gtk_label_set_single_line_mode(GTK_LABEL(label_text), FALSE);
     gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(entry), TRUE);
     gtk_text_view_set_editable(GTK_TEXT_VIEW(entry), TRUE);
-    gtk_widget_set_name(GTK_WIDGET(entry), msg->str_sender_id);
-    hildon_button_set_title(button_rply, STR_RPLY);
+    gtk_widget_set_name(GTK_WIDGET(entry), friend->str_id);
+    if (msg->str_recipient_name == NULL || strcmp(msg->str_recipient_name, "") == 0) {
+        hildon_button_set_title(button_rply, STR_RPLY);
+    } else {
+        hildon_button_set_title(button_rply, STR_1MOR);   
+    }
     hildon_button_set_title(button_send, STR_SEND);
-    hildon_button_set_title(button_sndr, msg->str_sender_name);
+    
+    hildon_button_set_title(button_sndr, friend->str_name);
+    
     gtk_button_set_relief(GTK_BUTTON(button_sndr), GTK_RELIEF_NONE);
     hildon_pannable_area_add_with_viewport (panarea, label_text);
     
